@@ -13,6 +13,8 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(IsHashRefWithData IsStringWithData);
 
+our $ObjectManagerDisabled = 1;
+
 =head1 NAME
 
 Kernel::GenericInterface::Mapping::Test - GenericInterface test data mapping backend
@@ -40,8 +42,9 @@ sub new {
     bless( $Self, $Type );
 
     # check needed params
-    for my $Needed (qw(DebuggerObject MainObject MappingConfig)) {
+    for my $Needed (qw(DebuggerObject MappingConfig)) {
         if ( !$Param{$Needed} ) {
+
             return {
                 Success      => 0,
                 ErrorMessage => "Got no $Needed!"
@@ -52,6 +55,7 @@ sub new {
 
     # check mapping config
     if ( !IsHashRefWithData( $Param{MappingConfig} ) ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'Got no MappingConfig as hash ref with content!',
         );
@@ -63,6 +67,7 @@ sub new {
         && !IsHashRefWithData( $Param{MappingConfig}->{Config} )
         )
     {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'Got MappingConfig with Data, but Data is no hash ref with content!',
         );
@@ -103,6 +108,7 @@ sub Map {
 
     # check data - only accept undef or hash ref
     if ( defined $Param{Data} && ref $Param{Data} ne 'HASH' ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'Got Data but it is not a hash ref in Mapping Test backend!'
         );
@@ -110,6 +116,7 @@ sub Map {
 
     # return if data is empty
     if ( !defined $Param{Data} || !%{ $Param{Data} } ) {
+
         return {
             Success => 1,
             Data    => {},
@@ -122,6 +129,7 @@ sub Map {
         || !defined $Self->{MappingConfig}->{Config}->{TestOption}
         )
     {
+
         return {
             Success => 1,
             Data    => $Param{Data},
@@ -130,6 +138,7 @@ sub Map {
 
     # check TestOption format
     if ( !IsStringWithData( $Self->{MappingConfig}->{Config}->{TestOption} ) ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'Got no TestOption as string with value!',
         );
