@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -69,24 +69,26 @@ one or more ticket entries in one call.
 
     my $Result = $OperationObject->Run(
         Data => {
-            UserLogin         => 'some agent login',                            # UserLogin or CustomerUserLogin or SessionID is
-                                                                                #   required
-            CustomerUserLogin => 'some customer login',
-            SessionID         => 123,
+            UserLogin            => 'some agent login',                            # UserLogin or CustomerUserLogin or SessionID is
+                                                                                   #   required
+            CustomerUserLogin    => 'some customer login',
+            SessionID            => 123,
 
-            Password          => 'some password',                                       # if UserLogin or customerUserLogin is sent then
-                                                                                #   Password is required
-            TicketID          => '32,33',                                       # required, could be coma separated IDs or an Array
-            DynamicFields     => 0,                                             # Optional, 0 as default. Indicate if Dynamic Fields
-                                                                                # should be included or not on the ticket content.
-            Extended          => 1,                                             # Optional, 0 as default
-            AllArticles       => 1,                                             # Optional, 0 as default. Set as 1 will include articles
-                                                                                # for tickets.
-            ArticleSenderType => [ $ArticleSenderType1, $ArticleSenderType2 ],  # Optional, only requested article sender types
-            ArticleOrder      => 'DESC',                                        # Optional, DESC,ASC - default is ASC
-            ArticleLimit      => 5,                                             # Optional
-            Attachments       => 1,                                             # Optional, 1 as default. If it's set with the value 1,
-                                                                                # attachments for articles will be included on ticket data
+            Password             => 'some password',                               # if UserLogin or customerUserLogin is sent then
+                                                                                   #   Password is required
+            TicketID             => '32,33',                                       # required, could be coma separated IDs or an Array
+            DynamicFields        => 0,                                             # Optional, 0 as default. Indicate if Dynamic Fields
+                                                                                   #     should be included or not on the ticket content.
+            Extended             => 1,                                             # Optional, 0 as default
+            AllArticles          => 1,                                             # Optional, 0 as default. Set as 1 will include articles
+                                                                                   #     for tickets.
+            ArticleSenderType    => [ $ArticleSenderType1, $ArticleSenderType2 ],  # Optional, only requested article sender types
+            ArticleOrder         => 'DESC',                                        # Optional, DESC,ASC - default is ASC
+            ArticleLimit         => 5,                                             # Optional
+            Attachments          => 1,                                             # Optional, 1 as default. If it's set with the value 1,
+                                                                                   # attachments for articles will be included on ticket data
+            HTMLBodyAsAttachment => 1                                              # Optional, If enabled the HTML body version of each article
+                                                                                   #    is added to the attachments list
         },
     );
 
@@ -288,6 +290,15 @@ sub Run {
         );
     }
 
+    # Get the list of dynamic fields for object article.
+    my $ArticleDynamicFieldList = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldList(
+        ObjectType => 'Article',
+        ResultType => 'HASH',
+    );
+
+    # Crate a lookup list for easy search
+    my %ArticleDynamicFieldLookup = reverse %{$ArticleDynamicFieldList};
+
     TICKET:
     for my $TicketID (@TicketIDs) {
 
@@ -305,18 +316,28 @@ sub Run {
         );
     }
 
-    my $DynamicFields     = $Param{Data}->{DynamicFields}     || 0;
-    my $Extended          = $Param{Data}->{Extended}          || 0;
-    my $AllArticles       = $Param{Data}->{AllArticles}       || 0;
-    my $ArticleSenderType = $Param{Data}->{ArticleSenderType} || '';
-    my $ArticleOrder      = $Param{Data}->{ArticleOrder}      || 'ASC';
-    my $ArticleLimit      = $Param{Data}->{ArticleLimit}      || 0;
-    my $Attachments       = $Param{Data}->{Attachments}       || 0;
-    my $ReturnData        = {
+    my $DynamicFields = $Param{Data}->{DynamicFields} || 0;
+    my $Extended      = $Param{Data}->{Extended}      || 0;
+    my $AllArticles   = $Param{Data}->{AllArticles}   || 0;
+    my $ArticleOrder  = $Param{Data}->{ArticleOrder}  || 'ASC';
+    my $ArticleLimit  = $Param{Data}->{ArticleLimit}  || 0;
+    my $Attachments   = $Param{Data}->{Attachments}   || 0;
+    my $ReturnData    = {
         Success => 1,
     };
     my @Item;
 
+    my $ArticleSenderType = '';
+    if ( IsArrayRefWithData( $Param{Data}->{ArticleSenderType} ) ) {
+        $ArticleSenderType = $Param{Data}->{ArticleSenderType};
+    }
+    elsif ( IsStringWithData( $Param{Data}->{ArticleSenderType} ) ) {
+        $ArticleSenderType = [ $Param{Data}->{ArticleSenderType} ]
+    }
+
+    # By default does not include HYML body as attachment (3) unless is explicitly requested (2).
+    my $StripPlainBodyAsAttachment = $Param{Data}->{HTMLBodyAsAttachment} ? 2 : 3;
+
     # start ticket loop
     TICKET:
     for my $TicketID (@TicketIDs) {
@@ -380,6 +401,7 @@ sub Run {
         if ( $UserType eq 'Customer' ) {
             $ArticleTypes = [ $TicketObject->ArticleTypeList( Type => 'Customer' ) ];
         }
+
         my @ArticleBoxRaw = $TicketObject->ArticleGet(
             TicketID          => $TicketID,
             ArticleSenderType => $ArticleSenderType,
@@ -401,7 +423,7 @@ sub Run {
             my %AtmIndex = $TicketObject->ArticleAttachmentIndex(
                 ContentPath                => $Article->{ContentPath},
                 ArticleID                  => $Article->{ArticleID},
-                StripPlainBodyAsAttachment => 3,
+                StripPlainBodyAsAttachment => $StripPlainBodyAsAttachment,
                 Article                    => $Article,
                 UserID                     => $UserID,
             );
@@ -437,14 +459,18 @@ sub Run {
 
             for my $ArticleRaw (@ArticleBoxRaw) {
                 my %Article;
-                my @DynamicFields;
+                my @ArticleDynamicFields;
 
                 # remove all dynamic fields form main article hash and set them into an array.
                 ATTRIBUTE:
                 for my $Attribute ( sort keys %{$ArticleRaw} ) {
 
                     if ( $Attribute =~ m{\A DynamicField_(.*) \z}msx ) {
-                        push @DynamicFields, {
+
+                        # Skip dynamic fields that are not for article object
+                        next ATTRIBUTE if ( !$ArticleDynamicFieldLookup{$1} );
+
+                        push @ArticleDynamicFields, {
                             Name  => $1,
                             Value => $ArticleRaw->{$Attribute},
                         };
@@ -455,8 +481,8 @@ sub Run {
                 }
 
                 # add dynamic fields array into 'DynamicField' hash key if any
-                if (@DynamicFields) {
-                    $Article{DynamicField} = \@DynamicFields;
+                if (@ArticleDynamicFields) {
+                    $Article{DynamicField} = \@ArticleDynamicFields;
                 }
 
                 push @ArticleBox, \%Article;
