@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,7 @@ use warnings;
 
 our $ObjectManagerDisabled = 1;
 
+use Kernel::Language qw(Translatable);
 use Kernel::System::VariableCheck qw(:all);
 
 sub new {
@@ -34,8 +35,9 @@ sub Run {
 
     my $ACLID = $ParamObject->GetParam( Param => 'ID' ) || '';
 
-    my $SynchronizeMessage
-        = 'ACL information from database is not in sync with the system configuration, please deploy all ACLs.';
+    my $SynchronizeMessage = Translatable(
+        'ACL information from database is not in sync with the system configuration, please deploy all ACLs.'
+    );
 
     my $SynchronizedMessageVisible = 0;
 
@@ -78,8 +80,9 @@ sub Run {
 
         if ( !$ACLImport->{Success} ) {
             my $Message = $ACLImport->{Message}
-                || 'ACLs could not be Imported due to a unknown error,'
-                . ' please check OTRS logs for more information';
+                || Translatable(
+                'ACLs could not be Imported due to a unknown error, please check OTRS logs for more information'
+                );
             return $LayoutObject->ErrorScreen(
                 Message => $Message,
             );
@@ -87,22 +90,27 @@ sub Run {
 
         if ( $ACLImport->{AddedACLs} ) {
             push @{ $Param{NotifyData} }, {
-                Info => 'The following ACLs have been added successfully: '
-                    . $ACLImport->{AddedACLs},
+                Info => $LayoutObject->{LanguageObject}->Translate(
+                    'The following ACLs have been added successfully: %s',
+                    $ACLImport->{AddedACLs}
+                ),
             };
         }
         if ( $ACLImport->{UpdatedACLs} ) {
             push @{ $Param{NotifyData} }, {
-                Info => 'The following ACLs have been updated successfully: '
-                    . $ACLImport->{UpdatedACLs},
+                Info => $LayoutObject->{LanguageObject}->Translate(
+                    'The following ACLs have been updated successfully: %s',
+                    $ACLImport->{UpdatedACLs}
+                ),
             };
         }
         if ( $ACLImport->{ACLErrors} ) {
             push @{ $Param{NotifyData} }, {
                 Priority => 'Error',
-                Info     => 'There where errors adding/updating the following ACLs: '
-                    . $ACLImport->{ACLErrors}
-                    . '. Please check the log file for more information.',
+                Info     => $LayoutObject->{LanguageObject}->Translate(
+                    'There where errors adding/updating the following ACLs: %s. Please check the log file for more information.',
+                    $ACLImport->{ACLErrors}
+                ),
             };
         }
 
@@ -163,14 +171,14 @@ sub Run {
 
             # add server error error class
             $Error{NameServerError}        = 'ServerError';
-            $Error{NameServerErrorMessage} = 'This field is required';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
         if ( !$GetParam->{ValidID} ) {
 
             # add server error error class
             $Error{ValidIDServerError}        = 'ServerError';
-            $Error{ValidIDServerErrorMessage} = 'This field is required';
+            $Error{ValidIDServerErrorMessage} = Translatable('This field is required');
         }
 
         # if there is an error return to edit screen
@@ -196,7 +204,7 @@ sub Run {
         # show error if can't create
         if ( !$ACLID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error creating the ACL",
+                Message => Translatable('There was an error creating the ACL'),
             );
         }
 
@@ -212,7 +220,7 @@ sub Run {
         # check for ACLID
         if ( !$ACLID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Need ACLID!",
+                Message => Translatable('Need ACLID!'),
             );
         }
 
@@ -225,7 +233,7 @@ sub Run {
         # check for valid ACL data
         if ( !IsHashRefWithData($ACLData) ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Could not get data for ACLID $ACLID",
+                Message => $LayoutObject->{LanguageObject}->Translate( 'Could not get data for ACLID %s', $ACLID ),
             );
         }
 
@@ -280,14 +288,14 @@ sub Run {
 
             # add server error error class
             $Error{NameServerError}        = 'ServerError';
-            $Error{NameServerErrorMessage} = 'This field is required';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
         if ( !$GetParam->{ValidID} ) {
 
             # add server error error class
             $Error{ValidIDServerError}        = 'ServerError';
-            $Error{ValidIDServerErrorMessage} = 'This field is required';
+            $Error{ValidIDServerErrorMessage} = Translatable('This field is required');
         }
 
         # if there is an error return to edit screen
@@ -316,7 +324,7 @@ sub Run {
         # show error if can't update
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error updating the ACL",
+                Message => Translatable('There was an error updating the ACL'),
             );
         }
 
@@ -359,7 +367,7 @@ sub Run {
 
                 # show error if can't set state
                 return $LayoutObject->ErrorScreen(
-                    Message => "There was an error setting the entity sync status.",
+                    Message => Translatable('There was an error setting the entity sync status.'),
                 );
             }
         }
@@ -367,7 +375,7 @@ sub Run {
 
             # show error if can't synch
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error synchronizing the ACLs.",
+                Message => Translatable('There was an error synchronizing the ACLs.'),
             );
         }
     }
@@ -398,7 +406,8 @@ sub Run {
             );
 
             if ( !$Success ) {
-                $DeleteResult{Message} = 'ACL $ACLID could not be deleted';
+                $DeleteResult{Message}
+                    = $LayoutObject->{LanguageObject}->Translate( 'ACL %s could not be deleted', $ACLID );
             }
 
             # build JSON output
@@ -446,7 +455,8 @@ sub Run {
 
             if ( !$ACLSingleData || !IsHashRefWithData($ACLSingleData) ) {
                 return $LayoutObject->ErrorScreen(
-                    Message => "There was an error getting data for ACL with ID " . $ACLID,
+                    Message => $LayoutObject->{LanguageObject}
+                        ->Translate( 'There was an error getting data for ACL with ID %s', $ACLID ),
                 );
             }
 
@@ -518,7 +528,7 @@ sub Run {
         # show error if can't create
         if ( !$ACLID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error creating the ACL",
+                Message => Translatable('There was an error creating the ACL'),
             );
         }
 
@@ -703,12 +713,12 @@ sub _ShowEdit {
 
     $Param{ACLKeysLevel4Prefixes} = $LayoutObject->BuildSelection(
         Data => {
-            ''            => 'Exact match',
-            '[Not]'       => 'Negated Exact match',
-            '[RegExp]'    => 'Regex',
-            '[regexp]'    => 'Regex (ignore case)',
-            '[NotRegExp]' => 'Negated Regex',
-            '[Notregexp]' => 'Negated Regex (ignore case)',
+            ''            => Translatable('Exact match'),
+            '[Not]'       => Translatable('Negated exact match'),
+            '[RegExp]'    => Translatable('Regular expression'),
+            '[regexp]'    => Translatable('Regular expression (ignore case)'),
+            '[NotRegExp]' => Translatable('Negated regular expression'),
+            '[Notregexp]' => Translatable('Negated regular expression (ignore case)'),
         },
         Name           => 'ItemPrefix',
         Class          => 'ItemPrefix',
