@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +11,8 @@ package Kernel::Modules::AdminCustomerCompany;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our $ObjectManagerDisabled = 1;
 
 sub new {
@@ -78,7 +80,7 @@ sub Run {
         $GetParam{CustomerCompanyID} = $ParamObject->GetParam( Param => 'CustomerCompanyID' );
 
         for my $Entry ( @{ $ConfigObject->Get('CustomerCompany')->{Map} } ) {
-            $GetParam{ $Entry->[0] } = $ParamObject->GetParam( Param => $Entry->[0] ) || '';
+            $GetParam{ $Entry->[0] } = $ParamObject->GetParam( Param => $Entry->[0] ) // '';
 
             # check mandatory fields
             if ( !$GetParam{ $Entry->[0] } && $Entry->[4] ) {
@@ -124,7 +126,7 @@ sub Run {
                 $Output .= $LayoutObject->NavigationBar(
                     Type => $NavigationBarType,
                 );
-                $Output .= $LayoutObject->Notify( Info => 'Customer company updated!' );
+                $Output .= $LayoutObject->Notify( Info => Translatable('Customer company updated!') );
                 $Output .= $LayoutObject->Output(
                     TemplateFile => 'AdminCustomerCompany',
                     Data         => \%Param,
@@ -146,7 +148,10 @@ sub Run {
         if ( $Errors{Duplicate} ) {
             $Output .= $LayoutObject->Notify(
                 Priority => 'Error',
-                Info     => "CustomerCompany $GetParam{CustomerID} already exists!.",
+                Info     => $LayoutObject->{LanguageObject}->Translate(
+                    'Customer Company %s already exists!',
+                    $GetParam{CustomerID},
+                ),
             );
         }
 
@@ -204,7 +209,7 @@ sub Run {
         my $CustomerCompanyID;
 
         for my $Entry ( @{ $ConfigObject->Get('CustomerCompany')->{Map} } ) {
-            $GetParam{ $Entry->[0] } = $ParamObject->GetParam( Param => $Entry->[0] ) || '';
+            $GetParam{ $Entry->[0] } = $ParamObject->GetParam( Param => $Entry->[0] ) // '';
 
             # check mandatory fields
             if ( !$GetParam{ $Entry->[0] } && $Entry->[4] ) {
@@ -247,7 +252,9 @@ sub Run {
                 $Output .= $LayoutObject->NavigationBar(
                     Type => $NavigationBarType,
                 );
-                $Output .= $LayoutObject->Notify( Info => 'Customer company added!' );
+                $Output .= $LayoutObject->Notify(
+                    Info => Translatable('Customer company added!'),
+                );
                 $Output .= $LayoutObject->Output(
                     TemplateFile => 'AdminCustomerCompany',
                     Data         => \%Param,
@@ -269,7 +276,10 @@ sub Run {
         if ( $Errors{Duplicate} ) {
             $Output .= $LayoutObject->Notify(
                 Priority => 'Error',
-                Info     => "CustomerCompany $CustomerCompanyID already exists!.",
+                Info     => $LayoutObject->{LanguageObject}->Translate(
+                    'Customer Company %s already exists!',
+                    $CustomerCompanyID,
+                ),
             );
         }
 
@@ -510,30 +520,42 @@ sub _Overview {
         );
     }
 
-    my %ListAll = $CustomerCompanyObject->CustomerCompanyList(
-        Search => '*',
-        Limit  => 99999,
-        Valid  => 0,
-    );
-
-    # same Limit as $Self->{CustomerCompanyMap}->{'CustomerCompanySearchListLimit'}
-    my $Limit = 250;
-
-    if ( keys %ListAll <= $Limit ) {
-        my $ListAll = keys %ListAll;
-        $LayoutObject->Block(
-            Name => 'OverviewHeader',
-            Data => {
-                ListAll => $ListAll,
-                Limit   => $Limit,
-            },
-        );
-    }
-
-    my %List = ();
-
     # if there are any registries to search, the table is filled and shown
     if ( $Param{Search} ) {
+
+        # get config object
+        my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+        # same Limit as $Self->{CustomerCompanyMap}->{'CustomerCompanySearchListLimit'}
+        # smallest Limit from all sources
+        my $Limit = 400;
+        SOURCE:
+        for my $Count ( '', 1 .. 10 ) {
+            next SOURCE if !$ConfigObject->Get("CustomerCompany$Count");
+            my $CustomerUserMap = $ConfigObject->Get("CustomerCompany$Count");
+            next SOURCE if !$CustomerUserMap->{CustomerCompanySearchListLimit};
+            if ( $CustomerUserMap->{CustomerCompanySearchListLimit} < $Limit ) {
+                $Limit = $CustomerUserMap->{CustomerCompanySearchListLimit};
+            }
+        }
+
+        my %ListAll = $CustomerCompanyObject->CustomerCompanyList(
+            Search => $Param{Search},
+            Limit  => $Limit + 1,
+            Valid  => 0,
+        );
+
+        if ( keys %ListAll <= $Limit ) {
+            my $ListAll = keys %ListAll;
+            $LayoutObject->Block(
+                Name => 'OverviewHeader',
+                Data => {
+                    ListAll => $ListAll,
+                    Limit   => $Limit,
+                },
+            );
+        }
+
         my %List = $CustomerCompanyObject->CustomerCompanyList(
             Search => $Param{Search},
             Valid  => 0,
@@ -561,8 +583,6 @@ sub _Overview {
         # get valid list
         my %ValidList = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
 
-        my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
         if ( !$ConfigObject->Get('CustomerCompany')->{Params}->{ForeignDB} ) {
             $LayoutObject->Block( Name => 'LocalDB' );
         }
