@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,7 @@ use strict;
 use warnings;
 
 use Kernel::System::CheckItem;
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -339,7 +340,7 @@ sub Run {
                         Search => $Search,
                     );
                     my $Output = $NavBar . $Note;
-                    $Output .= $LayoutObject->Notify( Info => 'Customer updated!' );
+                    $Output .= $LayoutObject->Notify( Info => Translatable('Customer updated!') );
                     $Output .= $LayoutObject->Output(
                         TemplateFile => 'AdminCustomerUser',
                         Data         => \%Param,
@@ -666,33 +667,44 @@ sub _Overview {
         );
     }
 
-    my %AllUsers = $CustomerUserObject->CustomerSearch(
-        Search => '*',
-        Limit  => 999999,
-        Valid  => 0,
-    );
-
-    # same Limit as $Self->{CustomerUserMap}->{CustomerUserSearchListLimit}
-    my $Limit = 250;
-
-    if ( keys %AllUsers <= $Limit ) {
-        my $ListAll = keys %AllUsers;
-        $LayoutObject->Block(
-            Name => 'OverviewHeader',
-            Data => {
-                ListAll => $ListAll,
-                Limit   => $Limit,
-            },
-        );
-    }
-
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
     # when there is no data to show, a message is displayed on the table with this colspan
     my $ColSpan = 6;
 
     if ( $Param{Search} ) {
 
+        # get config object
+        my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+        # same Limit as $Self->{CustomerUserMap}->{CustomerUserSearchListLimit}
+        # smallest Limit from all sources
+        my $Limit = 400;
+        SOURCE:
+        for my $Count ( '', 1 .. 10 ) {
+            next SOURCE if !$ConfigObject->Get("CustomerUser$Count");
+            my $CustomerUserMap = $ConfigObject->Get("CustomerUser$Count");
+            next SOURCE if !$CustomerUserMap->{CustomerUserSearchListLimit};
+            if ( $CustomerUserMap->{CustomerUserSearchListLimit} < $Limit ) {
+                $Limit = $CustomerUserMap->{CustomerUserSearchListLimit};
+            }
+        }
+
+        my %AllUsers = $CustomerUserObject->CustomerSearch(
+            Search => $Param{Search},
+            Limit  => $Limit + 1,
+            Valid  => 0,
+        );
+
+        if ( keys %AllUsers <= $Limit ) {
+            my $ListAll = keys %AllUsers;
+            $LayoutObject->Block(
+                Name => 'OverviewHeader',
+                Data => {
+                    ListAll => $ListAll,
+                    Limit   => $Limit,
+                },
+            );
+        }
+
         my %List = $CustomerUserObject->CustomerSearch(
             Search => $Param{Search},
             Valid  => 0,
@@ -717,7 +729,7 @@ sub _Overview {
             Data => \%Param,
         );
 
-        if ( $ConfigObject->Get('SwitchToCustomer') && $Self->{SwitchToCustomerPermission} )
+        if ( $ConfigObject->Get('SwitchToCustomer') && $Self->{SwitchToCustomerPermission} && $Param{Nav} ne 'None' )
         {
             $ColSpan = 7;
             $LayoutObject->Block(
