@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -34,7 +35,7 @@ sub Run {
         = int( $Kernel::OM->Get('Kernel::System::Web::Request')->GetParam( Param => 'WebserviceID' ) || 0 );
     if ( !$WebserviceID ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Need WebserviceID!",
+            Message => Translatable('Need WebserviceID!'),
         );
     }
 
@@ -44,7 +45,8 @@ sub Run {
 
     if ( !IsHashRefWithData($WebserviceData) ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not get data for WebserviceID $WebserviceID",
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not get data for WebserviceID %s', $WebserviceID ),
         );
     }
 
@@ -133,12 +135,12 @@ sub _Add {
 
     if ( !$InvokerType ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Need InvokerType",
+            Message => Translatable('Need InvokerType'),
         );
     }
     if ( !$Self->_InvokerTypeCheck( InvokerType => $InvokerType ) ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Invoker $InvokerType is not registered",
+            Message => $LayoutObject->{LanguageObject}->Translate( 'Invoker %s is not registered', $InvokerType ),
         );
     }
 
@@ -182,12 +184,13 @@ sub _AddAction {
     # uncorrectable errors
     if ( !$GetParam{InvokerType} ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Need InvokerType",
+            Message => Translatable('Need InvokerType'),
         );
     }
     if ( !$Self->_InvokerTypeCheck( InvokerType => $GetParam{InvokerType} ) ) {
         return $LayoutObject->ErrorScreen(
-            Message => "InvokerType $GetParam{InvokerType} is not registered",
+            Message => $LayoutObject->{LanguageObject}
+                ->Translate( 'InvokerType %s is not registered', $GetParam{InvokerType} ),
         );
     }
 
@@ -266,7 +269,7 @@ sub _Change {
 
     if ( !$Invoker ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Need Invoker",
+            Message => Translatable('Need Invoker'),
         );
     }
 
@@ -278,7 +281,8 @@ sub _Change {
         )
     {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not determine config for invoker $Invoker",
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not determine config for invoker %s', $Invoker ),
         );
     }
 
@@ -316,7 +320,7 @@ sub _ChangeAction {
 
         if ( !$GetParam{$Needed} ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Need $Needed",
+                Message => $LayoutObject->{LanguageObject}->Translate( 'Need %s', $Needed ),
             );
         }
     }
@@ -331,7 +335,8 @@ sub _ChangeAction {
         )
     {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not determine config for invoker $GetParam{OldInvoker}",
+            Message => $LayoutObject->{LanguageObject}
+                ->Translate( 'Could not determine config for invoker %s', $GetParam{OldInvoker} ),
         );
     }
 
@@ -710,7 +715,7 @@ sub _AddEvent {
 
         if ( !$GetParam{$Needed} ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Need $Needed",
+                Message => $LayoutObject->{LanguageObject}->Translate( 'Need %s', $Needed ),
             );
         }
     }
@@ -725,7 +730,8 @@ sub _AddEvent {
         )
     {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not determine config for invoker $GetParam{Invoker}",
+            Message => $LayoutObject->{LanguageObject}
+                ->Translate( 'Could not determine config for invoker %s', $GetParam{Invoker} ),
         );
     }
 
@@ -788,7 +794,7 @@ sub _DeleteEvent {
 
         if ( !$GetParam{$Needed} ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Need $Needed",
+                Message => $LayoutObject->{LanguageObject}->Translate( 'Need %s', $Needed ),
             );
         }
     }
@@ -803,7 +809,8 @@ sub _DeleteEvent {
         )
     {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not determine config for invoker $GetParam{Invoker}",
+            Message => $LayoutObject->{LanguageObject}
+                ->Translate( 'Could not determine config for invoker %s', $GetParam{Invoker} ),
         );
     }
 
@@ -856,11 +863,11 @@ sub _DeleteEvent {
     );
 }
 
-=item _InvokerTypeCheck()
-
-checks if a given InvokerType is registered in the system.
-
-=cut
+# =item _InvokerTypeCheck()
+#
+# checks if a given InvokerType is registered in the system.
+#
+# =cut
 
 sub _InvokerTypeCheck {
     my ( $Self, %Param ) = @_;
@@ -873,11 +880,11 @@ sub _InvokerTypeCheck {
     return ref $Invokers->{ $Param{InvokerType} } eq 'HASH' ? 1 : 0;
 }
 
-=item _MappingTypeCheck()
-
-checks if a given MappingType is registered in the system.
-
-=cut
+# =item _MappingTypeCheck()
+#
+# checks if a given MappingType is registered in the system.
+#
+# =cut
 
 sub _MappingTypeCheck {
     my ( $Self, %Param ) = @_;
