@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -62,21 +63,22 @@ sub Run {
         next LIBREQUIRED if $LibFound;
 
         return $LayoutObject->ErrorScreen(
-            Message => "Could not find required library $LibRequired",
+            Message => $LayoutObject->{LanguageObject}->Translate( 'Could not find required library %s', $LibRequired ),
         );
     }
 
     # check for valid action backend
     if ( !IsHashRefWithData($ActionsConfig) ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not get registered configuration for action type $ActionType",
+            Message => $LayoutObject->{LanguageObject}
+                ->Translate( 'Could not get registered configuration for action type %s', $ActionType ),
         );
     }
 
     # check for WebserviceID
     if ( !$WebserviceID ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Need WebserviceID!",
+            Message => Translatable('Need WebserviceID!'),
         );
     }
 
@@ -90,7 +92,8 @@ sub Run {
     # check for valid web service configuration
     if ( !IsHashRefWithData($WebserviceData) ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not get data for WebserviceID $WebserviceID",
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not get data for WebserviceID %s', $WebserviceID ),
         );
     }
 
@@ -100,7 +103,8 @@ sub Run {
     # check for valid action backend
     if ( !$ActionBackend ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not get backend for $ActionType $Action",
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not get backend for %s %s', $ActionType, $Action ),
         );
     }
 
@@ -187,7 +191,8 @@ sub Run {
         # check for successful web service update
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Could not update configuration data for WebserviceID $WebserviceID",
+                Message => $LayoutObject->{LanguageObject}
+                    ->Translate( 'Could not update configuration data for WebserviceID %s', $WebserviceID ),
             );
         }
 
