@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -38,7 +39,7 @@ sub Run {
 
     if ( !$WebserviceID ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Need WebserviceID!",
+            Message => Translatable('Need WebserviceID!'),
         );
     }
 
@@ -48,7 +49,8 @@ sub Run {
 
     if ( !IsHashRefWithData($WebserviceData) ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not get data for WebserviceID $WebserviceID",
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not get data for WebserviceID %s', $WebserviceID ),
         );
     }
 
@@ -219,7 +221,9 @@ sub _ExportWebserviceHistory {
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
     if ( !$Param{WebserviceHistoryID} ) {
-        $LayoutObject->FatalError( Message => "Got no WebserviceHistoryID!" );
+        $LayoutObject->FatalError(
+            Message => Translatable('Got no WebserviceHistoryID!'),
+        );
     }
 
     my $WebserviceHistoryID = $Param{WebserviceHistoryID};
@@ -232,7 +236,8 @@ sub _ExportWebserviceHistory {
     # check for valid web service configuration
     if ( !IsHashRefWithData($WebserviceHistoryData) ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Could not get history data for WebserviceHistoryID $WebserviceHistoryID",
+            Message => $LayoutObject->{LanguageObject}
+                ->Translate( 'Could not get history data for WebserviceHistoryID %s', $WebserviceHistoryID ),
         );
     }
 
@@ -257,7 +262,9 @@ sub _RollbackWebserviceHistory {
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
     if ( !$Param{WebserviceHistoryID} ) {
-        $LayoutObject->FatalError( Message => "Got no WebserviceHistoryID!" );
+        $LayoutObject->FatalError(
+            Message => Translatable('Got no WebserviceHistoryID!'),
+        );
     }
 
     my $WebserviceID        = $Param{WebserviceID};
