@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -206,6 +206,11 @@ sub Run {
         # if no errors occurred
         if ( !%Errors ) {
 
+            if ( $GetParam{Password} eq 'otrs-dummy-password-placeholder' ) {
+                my %OriginalData = $MailAccount->MailAccountGet(%GetParam);
+                $GetParam{Password} = $OriginalData{Password};
+            }
+
             # update mail account
             my $Update = $MailAccount->MailAccountUpdate(
                 %GetParam,
