@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -195,6 +195,8 @@ sub Run {
         my $Ok;
         my $ArticleFilterMissing;
 
+        $GetParam{Data}->{NotificationType} = ['Ticket'];
+
         # checking if article filter exist if necessary
         if (
             grep { $_ eq 'ArticleCreate' || $_ eq 'ArticleSend' }
@@ -226,7 +228,7 @@ sub Run {
             $Self->_Overview();
             my $Output = $LayoutObject->Header();
             $Output .= $LayoutObject->NavigationBar();
-            $Output .= $LayoutObject->Notify( Info => 'Updated!' );
+            $Output .= $LayoutObject->Notify( Info => Translatable('Notification updated!') );
             $Output .= $LayoutObject->Output(
                 TemplateFile => 'AdminNotificationEvent',
                 Data         => \%Param,
@@ -404,6 +406,8 @@ sub Run {
         my $ID;
         my $ArticleFilterMissing;
 
+        $GetParam{Data}->{NotificationType} = ['Ticket'];
+
         # define ServerError Message if necessary
         if (
             grep { $_ eq 'ArticleCreate' || $_ eq 'ArticleSend' }
@@ -438,7 +442,7 @@ sub Run {
             $Self->_Overview();
             my $Output = $LayoutObject->Header();
             $Output .= $LayoutObject->NavigationBar();
-            $Output .= $LayoutObject->Notify( Info => 'Added!' );
+            $Output .= $LayoutObject->Notify( Info => Translatable('Notification added!') );
             $Output .= $LayoutObject->Output(
                 TemplateFile => 'AdminNotificationEvent',
                 Data         => \%Param,
@@ -530,7 +534,8 @@ sub Run {
 
             if ( !IsHashRefWithData( \%NotificationSingleData ) ) {
                 return $LayoutObject->ErrorScreen(
-                    Message => "There was an error getting data for Notification with ID " . $NotificationID,
+                    Message => $LayoutObject->{LanguageObject}
+                        ->Translate( 'There was an error getting data for Notification with ID:%s!', $NotificationID ),
                 );
             }
 
@@ -584,7 +589,7 @@ sub Run {
         );
         if ( !IsHashRefWithData( \%NotificationData ) ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Unknown Notification $NotificationID!",
+                Message => $LayoutObject->{LanguageObject}->Translate( 'Unknown Notification %s!', $NotificationID ),
             );
         }
 
@@ -605,7 +610,7 @@ sub Run {
         # show error if can't create
         if ( !$NewNotificationID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error creating the Notification",
+                Message => Translatable("There was an error creating the Notification"),
             );
         }
 
@@ -637,8 +642,9 @@ sub Run {
 
         if ( !$NotificationImport->{Success} ) {
             my $Message = $NotificationImport->{Message}
-                || 'Notifications could not be Imported due to a unknown error,'
-                . ' please check OTRS logs for more information';
+                || Translatable(
+                'Notifications could not be Imported due to a unknown error, please check OTRS logs for more information'
+                );
             return $LayoutObject->ErrorScreen(
                 Message => $Message,
             );
@@ -646,22 +652,27 @@ sub Run {
 
         if ( $NotificationImport->{AddedNotifications} ) {
             push @{ $Param{NotifyData} }, {
-                Info => 'The following Notifications have been added successfully: '
-                    . $NotificationImport->{AddedNotifications},
+                Info => $LayoutObject->{LanguageObject}->Translate(
+                    'The following Notifications have been added successfully: %s',
+                    $NotificationImport->{AddedNotifications}
+                ),
             };
         }
         if ( $NotificationImport->{UpdatedNotifications} ) {
             push @{ $Param{NotifyData} }, {
-                Info => 'The following Notifications have been updated successfully: '
-                    . $NotificationImport->{UpdatedNotifications},
+                Info => $LayoutObject->{LanguageObject}->Translate(
+                    'The following Notifications have been updated successfully: %s',
+                    $NotificationImport->{UpdatedNotifications}
+                ),
             };
         }
         if ( $NotificationImport->{NotificationErrors} ) {
             push @{ $Param{NotifyData} }, {
                 Priority => 'Error',
-                Info     => 'There where errors adding/updating the following Notifications: '
-                    . $NotificationImport->{NotificationErrors}
-                    . '. Please check the log file for more information.',
+                Info     => $LayoutObject->{LanguageObject}->Translate(
+                    'There where errors adding/updating the following Notifications: %s. Please check the log file for more information.',
+                    $NotificationImport->{NotificationErrors}
+                ),
             };
         }
 
@@ -922,7 +933,7 @@ sub _Edit {
         # get list type
         my %Service = $Kernel::OM->Get('Kernel::System::Service')->ServiceList(
             Valid        => 1,
-            KeepChildren => 1,
+            KeepChildren => $ConfigObject->Get('Ticket::Service::KeepChildren') // 0,
             UserID       => $Self->{UserID},
         );
         $Param{ServicesStrg} = $LayoutObject->BuildSelection(
