@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,8 @@ package Kernel::Modules::AdminQueue;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our $ObjectManagerDisabled = 1;
 
 sub new {
@@ -123,8 +125,8 @@ sub Run {
             my $Output = $LayoutObject->Header();
             $Output .= $LayoutObject->NavigationBar();
             $Output .= $LayoutObject->Warning(
-                Message => 'Don\'t use :: in queue name!',
-                Comment => 'Click back and change it!',
+                Message => Translatable('Don\'t use :: in queue name!'),
+                Comment => Translatable('Click back and change it!'),
             );
             $Output .= $LayoutObject->Footer();
             return $Output;
@@ -222,7 +224,7 @@ sub Run {
 
                 my $Output = $LayoutObject->Header();
                 $Output .= $LayoutObject->NavigationBar();
-                $Output .= $LayoutObject->Notify( Info => 'Queue updated!' );
+                $Output .= $LayoutObject->Notify( Info => Translatable('Queue updated!') );
                 $Output .= $LayoutObject->Output(
                     TemplateFile => 'AdminQueue',
                     Data         => \%Param,
@@ -299,8 +301,8 @@ sub Run {
             my $Output = $LayoutObject->Header();
             $Output .= $LayoutObject->NavigationBar();
             $Output .= $LayoutObject->Warning(
-                Message => 'Don\'t use :: in queue name!',
-                Comment => 'Click back and change it!',
+                Message => Translatable('Don\'t use :: in queue name!'),
+                Comment => Translatable('Click back and change it!'),
             );
             $Output .= $LayoutObject->Footer();
 
@@ -640,7 +642,7 @@ sub _Edit {
     }
     $Param{DefaultSignKeyOption} = $LayoutObject->BuildSelection(
         Data => {
-            '' => '-none-',
+            '' => Translatable('-none-'),
             %DefaultSignKeyList
         },
         Name       => 'DefaultSignKey',
@@ -671,10 +673,12 @@ sub _Edit {
     );
     my %Calendar = ( '' => '-' );
 
-    for my $Number ( '', 1 .. 50 ) {
-        if ( $ConfigObject->Get("TimeVacationDays::Calendar$Number") ) {
-            $Calendar{$Number} = "Calendar $Number - "
-                . $ConfigObject->Get( "TimeZone::Calendar" . $Number . "Name" );
+    my $Maximum = $ConfigObject->Get("MaximumCalendarNumber") || 50;
+
+    for my $CalendarNumber ( '', 1 .. $Maximum ) {
+        if ( $ConfigObject->Get("TimeVacationDays::Calendar$CalendarNumber") ) {
+            $Calendar{$CalendarNumber} = "Calendar $CalendarNumber - "
+                . $ConfigObject->Get( "TimeZone::Calendar" . $CalendarNumber . "Name" );
         }
     }
     $Param{CalendarOption} = $LayoutObject->BuildSelection(
