@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,8 @@ use warnings;
 
 our $ObjectManagerDisabled = 1;
 
+use Kernel::Language qw(Translatable);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -79,7 +81,9 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Upload' ) {
 
         if ( !$ConfigObject->Get('ConfigImportAllowed') ) {
-            return $LayoutObject->FatalError( Message => "Import not allowed!" );
+            return $LayoutObject->FatalError(
+                Message => Translatable('Import not allowed!'),
+            );
         }
 
         # challenge token check for write action
@@ -91,7 +95,7 @@ sub Run {
         );
         if ( !%UploadStuff ) {
             return $LayoutObject->ErrorScreen(
-                Message => 'Need File!',
+                Message => Translatable('Need File!'),
             );
         }
         elsif ( $SysConfigObject->Upload( Content => $UploadStuff{Content} ) ) {
@@ -162,7 +166,9 @@ sub Run {
                     Valid => $Active,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
                 next ITEM;
             }
@@ -180,7 +186,9 @@ sub Run {
                     Valid => $Active,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -197,7 +205,9 @@ sub Run {
                     Valid => $Active,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -212,7 +222,9 @@ sub Run {
                     Valid => $Active,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -330,7 +342,9 @@ sub Run {
                     %NoValidationOption,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -371,7 +385,9 @@ sub Run {
                     %NoValidationOption,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -582,7 +598,9 @@ sub Run {
                     Valid => $Active,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -629,7 +647,9 @@ sub Run {
                     Valid => $Active,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -676,7 +696,9 @@ sub Run {
                 );
 
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -697,7 +719,9 @@ sub Run {
                     Valid => $Active,
                 );
                 if ( !$Update ) {
-                    $LayoutObject->FatalError( Message => "Can't write ConfigItem!" );
+                    $LayoutObject->FatalError(
+                        Message => Translatable('Can\'t write ConfigItem!'),
+                    );
                 }
             }
 
@@ -952,13 +976,13 @@ sub Run {
         );
 
         # list Groups
-        my %List = $SysConfigObject->ConfigGroupList();
+        my %GroupList = $SysConfigObject->ConfigGroupList();
 
         $Group = $ParamObject->GetParam( Param => 'SysConfigGroup' );
 
         # create select Box
         $Data{List} = $LayoutObject->BuildSelection(
-            Data         => \%List,
+            Data         => \%GroupList,
             SelectedID   => $Group,
             Name         => 'SysConfigGroup',
             Translation  => 0,
@@ -981,16 +1005,17 @@ sub Run {
 
         $LayoutObject->Block( Name => 'OverviewResult' );
 
-        %List = $SysConfigObject->ConfigSubGroupList( Name => $Group );
+        my %SubGroupList;
+        %SubGroupList = $SysConfigObject->ConfigSubGroupList( Name => $Group ) if $Group;
 
         # if there are any results, they are shown
-        if (%List) {
-            for ( sort keys %List ) {
+        if (%SubGroupList) {
+            for my $Item ( sort keys %SubGroupList ) {
                 $LayoutObject->Block(
                     Name => 'Row',
                     Data => {
-                        SubGroup      => $_,
-                        SubGroupCount => $List{$_},
+                        SubGroup      => $Item,
+                        SubGroupCount => $SubGroupList{$Item},
                         Group         => $Group,
                     },
                 );
@@ -1164,12 +1189,19 @@ sub ListConfigItem {
                 $Default = $Option->{Item}->[$Index]->{Content};
             }
         }
+        my $Translate = 1;
+        if ( $Option->{Location} ) {
+
+            # Entries coming from the file system should not be translated.
+            $Translate = 0;
+        }
         my $PulldownMenu = $LayoutObject->BuildSelection(
-            Data       => \%Hash,
-            SelectedID => $Option->{SelectedID},
-            Name       => $ItemHash{Name},
-            Disabled   => $ReadOnlyAttribute ? 1 : 0,
-            Class      => 'Modernize',
+            Data        => \%Hash,
+            SelectedID  => $Option->{SelectedID},
+            Name        => $ItemHash{Name},
+            Disabled    => $ReadOnlyAttribute ? 1 : 0,
+            Class       => 'Modernize',
+            Translation => $Translate,
         );
         $LayoutObject->Block(
             Name => 'ConfigElementSelect',
