@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +11,8 @@ package Kernel::Modules::AdminType;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our $ObjectManagerDisabled = 1;
 
 sub new {
@@ -38,7 +40,7 @@ sub Run {
         my %Data = $TypeObject->TypeGet( ID => $ID );
         if ( !%Data ) {
             return $LayoutObject->ErrorScreen(
-                Message => 'Need Type!',
+                Message => Translatable('Need Type!'),
             );
         }
         my $Output = $LayoutObject->Header();
@@ -79,7 +81,7 @@ sub Run {
         my %Data = $TypeObject->TypeGet( ID => $GetParam{ID} );
         if ( !%Data ) {
             return $LayoutObject->ErrorScreen(
-                Message => 'Need Type!',
+                Message => Translatable('Need Type!'),
             );
         }
 
@@ -106,7 +108,7 @@ sub Run {
                 $Self->_Overview();
                 my $Output = $LayoutObject->Header();
                 $Output .= $LayoutObject->NavigationBar();
-                $Output .= $LayoutObject->Notify( Info => 'Type updated!' );
+                $Output .= $LayoutObject->Notify( Info => Translatable('Type updated!') );
                 $Output .= $LayoutObject->Output(
                     TemplateFile => 'AdminType',
                     Data         => \%Param,
@@ -193,7 +195,7 @@ sub Run {
                 $Self->_Overview();
                 my $Output = $LayoutObject->Header();
                 $Output .= $LayoutObject->NavigationBar();
-                $Output .= $LayoutObject->Notify( Info => 'Type added!' );
+                $Output .= $LayoutObject->Notify( Info => Translatable('Type added!') );
                 $Output .= $LayoutObject->Output(
                     TemplateFile => 'AdminType',
                     Data         => \%Param,
