@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -34,18 +34,33 @@ sub Run {
     my $LayoutObject       = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
     my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
     my $ConfigObject       = $Kernel::OM->Get('Kernel::Config');
+    my $TicketObject       = $Kernel::OM->Get('Kernel::System::Ticket');
 
-    my $AutoCompleteConfig = $ConfigObject->Get('AutoComplete::Agent')->{CustomerSearch};
-    my $MaxResults = $AutoCompleteConfig->{MaxResultsDisplayed} || 20;
+    my $AutoCompleteConfig            = $ConfigObject->Get('AutoComplete::Agent')->{CustomerSearch};
+    my $MaxResults                    = $AutoCompleteConfig->{MaxResultsDisplayed} || 20;
+    my $IncludeUnknownTicketCustomers = int( $ParamObject->GetParam( Param => 'IncludeUnknownTicketCustomers' ) || 0 );
+    my $SearchTerm                    = $ParamObject->GetParam( Param => 'Term' ) || '';
 
     if ( $Self->{Subaction} eq 'SearchCustomerID' ) {
 
-        my @CustomerIDs = $CustomerUserObject->CustomerIDList(
-            SearchTerm => $ParamObject->GetParam( Param => 'Term' ) || '',
-        );
+        # build result list
+        my $UnknownTicketCustomerList;
+
+        if ($IncludeUnknownTicketCustomers) {
+
+            # add customers that are not saved in any backend
+            $UnknownTicketCustomerList = $TicketObject->SearchUnknownTicketCustomers(
+                SearchTerm => $SearchTerm,
+            );
+        }
 
         my %CustomerCompanyList = $Kernel::OM->Get('Kernel::System::CustomerCompany')->CustomerCompanyList(
-            Search => $ParamObject->GetParam( Param => 'Term' ) || '',
+            Search => $SearchTerm,
+        );
+        map { $CustomerCompanyList{$_} = $UnknownTicketCustomerList->{$_} } keys %{$UnknownTicketCustomerList};
+
+        my @CustomerIDs = $CustomerUserObject->CustomerIDList(
+            SearchTerm => $SearchTerm,
         );
 
         # add CustomerIDs for which no CustomerCompany are registered
@@ -63,16 +78,19 @@ sub Run {
 
         }
 
-        # build result list
         my @Result;
+
         CUSTOMERID:
         for my $CustomerID ( sort keys %CustomerCompanyList ) {
-            push @Result,
-                {
-                Label => $CustomerCompanyList{$CustomerID},
-                Value => $CustomerID
-                };
+            if ( !( grep { $_->{Value} eq $CustomerID } @Result ) ) {
+                push @Result,
+                    {
+                    Label => $CustomerCompanyList{$CustomerID},
+                    Value => $CustomerID
+                    };
+            }
             last CUSTOMERID if scalar @Result >= $MaxResults;
+
         }
 
         my $JSON = $LayoutObject->JSONEncode(
@@ -88,26 +106,37 @@ sub Run {
     }
     elsif ( $Self->{Subaction} eq 'SearchCustomerUser' ) {
 
+        my $UnknownTicketCustomerList;
+
+        if ($IncludeUnknownTicketCustomers) {
+
+            # add customers that are not saved in any backend
+            $UnknownTicketCustomerList = $TicketObject->SearchUnknownTicketCustomers(
+                SearchTerm => $SearchTerm,
+            );
+        }
+
         my %CustomerList = $CustomerUserObject->CustomerSearch(
-            Search => $ParamObject->GetParam( Param => 'Term' ) || '',
+            Search => $SearchTerm,
         );
+        map { $CustomerList{$_} = $UnknownTicketCustomerList->{$_} } keys %{$UnknownTicketCustomerList};
 
         my @Result;
 
-        my $Count = 1;
-
         CUSTOMERLOGIN:
         for my $CustomerLogin ( sort keys %CustomerList ) {
             my %CustomerData = $CustomerUserObject->CustomerUserDataGet(
                 User => $CustomerLogin,
             );
-            push @Result,
-                {
-                Label => $CustomerList{$CustomerLogin},
-                Value => $CustomerData{UserCustomerID}
-                };
+            if ( !( grep { $_->{Value} eq $CustomerData{UserCustomerID} } @Result ) ) {
+                push @Result,
+                    {
+                    Label => $CustomerList{$CustomerLogin},
+                    Value => $CustomerData{UserCustomerID}
+                    };
+            }
+            last CUSTOMERLOGIN if scalar @Result >= $MaxResults;
 
-            last CUSTOMERLOGIN if $Count++ >= $MaxResults;
         }
 
         my $JSON = $LayoutObject->JSONEncode(
