@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,8 @@ use warnings;
 
 our $ObjectManagerDisabled = 1;
 
+use Kernel::Language qw(Translatable);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -81,7 +83,9 @@ sub Run {
         # check group param
         my @Groups = $ParamObject->GetArray( Param => 'Group' );
         if ( !@Groups ) {
-            return $LayoutObject->ErrorScreen( Message => 'Param Group is required!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('Param Group is required!'),
+            );
         }
 
         for my $Group (@Groups) {
@@ -89,7 +93,9 @@ sub Run {
             # check preferences setting
             my %Preferences = %{ $Kernel::OM->Get('Kernel::Config')->Get('PreferencesGroups') };
             if ( !$Preferences{$Group} ) {
-                return $LayoutObject->ErrorScreen( Message => "No such config for $Group" );
+                return $LayoutObject->ErrorScreen(
+                    Message => $LayoutObject->{LanguageObject}->Translate( 'No such config for %s', $Group ),
+                );
             }
 
             # get user data
