@@ -11,8 +11,9 @@ package Kernel::Modules::AgentTicketLockedView;
 use strict;
 use warnings;
 
-use Kernel::System::JSON;
-use Kernel::System::DynamicField;
+our $ObjectManagerDisabled = 1;
+
+use Kernel::Language qw(Translatable);
 use Kernel::System::VariableCheck qw(:all);
 
 sub new {
@@ -22,59 +23,55 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check all needed objects
-    for (qw(ParamObject DBObject QueueObject LayoutObject ConfigObject LogObject UserObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
-        }
-    }
-
-    $Self->{Config} = $Self->{ConfigObject}->Get("Ticket::Frontend::$Self->{Action}");
-
-    # create additional objects
-    $Self->{JSONObject}         = Kernel::System::JSON->new( %{$Self} );
-    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
-    $Self->{Filter}             = $Self->{ParamObject}->GetParam( Param => 'Filter' ) || 'All';
-    $Self->{View}               = $Self->{ParamObject}->GetParam( Param => 'View' ) || '';
-
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $SortBy = $Self->{ParamObject}->GetParam( Param => 'SortBy' )
-        || $Self->{Config}->{'SortBy::Default'}
+    # get needed object
+    my $ConfigObject  = $Kernel::OM->Get('Kernel::Config');
+    my $ParamObject   = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $SessionObject = $Kernel::OM->Get('Kernel::System::AuthSession');
+
+    my $Config = $ConfigObject->Get("Ticket::Frontend::$Self->{Action}");
+
+    my $SortBy = $ParamObject->GetParam( Param => 'SortBy' )
+        || $Config->{'SortBy::Default'}
         || 'Age';
-    my $OrderBy = $Self->{ParamObject}->GetParam( Param => 'OrderBy' )
-        || $Self->{Config}->{'Order::Default'}
+    my $OrderBy = $ParamObject->GetParam( Param => 'OrderBy' )
+        || $Config->{'Order::Default'}
         || 'Up';
 
     # store last screen
-    $Self->{SessionObject}->UpdateSessionID(
+    $SessionObject->UpdateSessionID(
         SessionID => $Self->{SessionID},
         Key       => 'LastScreenView',
         Value     => $Self->{RequestedURL},
     );
 
     # store last queue screen
-    $Self->{SessionObject}->UpdateSessionID(
+    $SessionObject->UpdateSessionID(
         SessionID => $Self->{SessionID},
         Key       => 'LastScreenOverview',
         Value     => $Self->{RequestedURL},
     );
 
+    # get needed objects
+    my $JSONObject = $Kernel::OM->Get('Kernel::System::JSON');
+    my $UserObject = $Kernel::OM->Get('Kernel::System::User');
+
     # get filters stored in the user preferences
-    my %Preferences = $Self->{UserObject}->GetPreferences(
+    my %Preferences = $UserObject->GetPreferences(
         UserID => $Self->{UserID},
     );
     my $StoredFiltersKey = 'UserStoredFilterColumns-' . $Self->{Action};
-    my $StoredFilters    = $Self->{JSONObject}->Decode(
+    my $StoredFilters    = $JSONObject->Decode(
         Data => $Preferences{$StoredFiltersKey},
     );
 
     # delete stored filters if needed
-    if ( $Self->{ParamObject}->GetParam( Param => 'DeleteFilters' ) ) {
+    if ( $ParamObject->GetParam( Param => 'DeleteFilters' ) ) {
         $StoredFilters = {};
     }
 
@@ -87,7 +84,7 @@ sub Run {
         )
     {
         # get column filter from web request
-        my $FilterValue = $Self->{ParamObject}->GetParam( Param => 'ColumnFilter' . $ColumnName )
+        my $FilterValue = $ParamObject->GetParam( Param => 'ColumnFilter' . $ColumnName )
             || '';
 
         # if filter is not present in the web request, try with the user preferences
@@ -107,10 +104,12 @@ sub Run {
 
         if ( $ColumnName eq 'CustomerID' ) {
             push @{ $ColumnFilter{$ColumnName} }, $FilterValue;
+            push @{ $ColumnFilter{ $ColumnName . 'Raw' } }, $FilterValue;
             $GetColumnFilter{$ColumnName} = $FilterValue;
         }
         elsif ( $ColumnName eq 'CustomerUserID' ) {
-            push @{ $ColumnFilter{CustomerUserLogin} }, $FilterValue;
+            push @{ $ColumnFilter{CustomerUserLogin} },    $FilterValue;
+            push @{ $ColumnFilter{CustomerUserLoginRaw} }, $FilterValue;
             $GetColumnFilter{$ColumnName} = $FilterValue;
         }
         else {
@@ -120,7 +119,7 @@ sub Run {
     }
 
     # get all dynamic fields
-    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+    $Self->{DynamicField} = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldListGet(
         Valid      => 1,
         ObjectType => ['Ticket'],
     );
@@ -131,7 +130,7 @@ sub Run {
         next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
         # get filter from web request
-        my $FilterValue = $Self->{ParamObject}->GetParam(
+        my $FilterValue = $ParamObject->GetParam(
             Param => 'ColumnFilterDynamicField_' . $DynamicFieldConfig->{Name}
         );
 
@@ -150,6 +149,9 @@ sub Run {
         $GetColumnFilter{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = $FilterValue;
     }
 
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     # starting with page ...
     my $Refresh = '';
     if ( $Self->{UserRefreshTime} ) {
@@ -157,12 +159,10 @@ sub Run {
     }
     my $Output;
     if ( $Self->{Subaction} ne 'AJAXFilterUpdate' ) {
-        $Output = $Self->{LayoutObject}->Header(
+        $Output = $LayoutObject->Header(
             Refresh => $Refresh,
         );
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Print( Output => \$Output );
-        $Output = '';
+        $Output .= $LayoutObject->NavigationBar();
     }
 
     # get locked  viewable tickets...
@@ -173,7 +173,7 @@ sub Run {
 
     my %Filters = (
         All => {
-            Name   => 'All',
+            Name   => Translatable('All'),
             Prio   => 1000,
             Search => {
                 Locks      => [ 'lock', 'tmp_lock' ],
@@ -185,12 +185,12 @@ sub Run {
             },
         },
         New => {
-            Name   => 'New Article',
+            Name   => Translatable('New Article'),
             Prio   => 1001,
             Search => {
-                Locks      => [ 'lock', 'tmp_lock' ],
-                OwnerIDs   => [ $Self->{UserID} ],
-                TicketFlag => {
+                Locks         => [ 'lock', 'tmp_lock' ],
+                OwnerIDs      => [ $Self->{UserID} ],
+                NotTicketFlag => {
                     Seen => 1,
                 },
                 TicketFlagUserID => $Self->{UserID},
@@ -201,7 +201,7 @@ sub Run {
             },
         },
         Reminder => {
-            Name   => 'Pending',
+            Name   => Translatable('Pending'),
             Prio   => 1002,
             Search => {
                 Locks      => [ 'lock',             'tmp_lock' ],
@@ -214,7 +214,7 @@ sub Run {
             },
         },
         ReminderReached => {
-            Name   => 'Reminder Reached',
+            Name   => Translatable('Reminder Reached'),
             Prio   => 1003,
             Search => {
                 Locks                         => [ 'lock', 'tmp_lock' ],
@@ -229,109 +229,79 @@ sub Run {
         },
     );
 
+    my $Filter = $ParamObject->GetParam( Param => 'Filter' ) || 'All';
+
     # check if filter is valid
-    if ( !$Filters{ $Self->{Filter} } ) {
-        $Self->{LayoutObject}->FatalError( Message => "Invalid Filter: $Self->{Filter}!" );
+    if ( !$Filters{$Filter} ) {
+        $LayoutObject->FatalError(
+            Message => $LayoutObject->{LanguageObject}->Translate( 'Invalid Filter: %s!', $Filter ),
+        );
     }
 
     # do shown tickets lookup
     my $Limit = 10_000;
 
-    my $ElementChanged = $Self->{ParamObject}->GetParam( Param => 'ElementChanged' ) || '';
+    my $ElementChanged = $ParamObject->GetParam( Param => 'ElementChanged' ) || '';
     my $HeaderColumn = $ElementChanged;
     $HeaderColumn =~ s{\A ColumnFilter }{}msxg;
     my @OriginalViewableTickets;
     my @ViewableTickets;
     my $ViewableTicketCount = 0;
 
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
     # get ticket values
     if (
         !IsStringWithData($HeaderColumn)
         || (
             IsStringWithData($HeaderColumn)
             && (
-                $Self->{ConfigObject}->Get('OnlyValuesOnTicket') ||
+                $ConfigObject->Get('OnlyValuesOnTicket') ||
                 $HeaderColumn eq 'CustomerID' ||
                 $HeaderColumn eq 'CustomerUserID'
             )
         )
         )
     {
-        @OriginalViewableTickets = $Self->{TicketObject}->TicketSearch(
-            %{ $Filters{ $Self->{Filter} }->{Search} },
+        @OriginalViewableTickets = $TicketObject->TicketSearch(
+            %{ $Filters{$Filter}->{Search} },
             Limit  => $Limit,
             Result => 'ARRAY',
         );
 
-        @ViewableTickets = $Self->{TicketObject}->TicketSearch(
-            %{ $Filters{ $Self->{Filter} }->{Search} },
+        @ViewableTickets = $TicketObject->TicketSearch(
+            %{ $Filters{$Filter}->{Search} },
             %ColumnFilter,
             Result => 'ARRAY',
             Limit  => 1_000,
         );
     }
 
-    # prepare shown tickets for new article tickets
-    if ( $Self->{Filter} eq 'New' ) {
-
-        my @OriginalViewableTicketsAll = $Self->{TicketObject}->TicketSearch(
-            %{ $Filters{All}->{Search} },
-            Result => 'ARRAY',
-        );
-
-        my %OriginalViewableTicketsNotNew;
-        for my $TicketID (@OriginalViewableTickets) {
-            $OriginalViewableTicketsNotNew{$TicketID} = 1;
-        }
-
-        my @OriginalViewableTicketsTmp;
-        for my $TicketIDAll (@OriginalViewableTicketsAll) {
-            next if $OriginalViewableTicketsNotNew{$TicketIDAll};
-            push @OriginalViewableTicketsTmp, $TicketIDAll;
-        }
-        @OriginalViewableTickets = @OriginalViewableTicketsTmp;
-
-        my @ViewableTicketsAll = $Self->{TicketObject}->TicketSearch(
-            %{ $Filters{All}->{Search} },
-            %ColumnFilter,
-            Result => 'ARRAY',
-            Limit  => 1_000,
-        );
-
-        my %ViewableTicketsNotNew;
-        for my $TicketID (@ViewableTickets) {
-            $ViewableTicketsNotNew{$TicketID} = 1;
-        }
-
-        my @ViewableTicketsTmp;
-        for my $TicketIDAll (@ViewableTicketsAll) {
-            next if $ViewableTicketsNotNew{$TicketIDAll};
-            push @ViewableTicketsTmp, $TicketIDAll;
-        }
-        @ViewableTickets = @ViewableTicketsTmp;
-    }
+    my $View = $ParamObject->GetParam( Param => 'View' ) || '';
 
     if ( $Self->{Subaction} eq 'AJAXFilterUpdate' ) {
 
-        my $FilterContent = $Self->{LayoutObject}->TicketListShow(
+        my $FilterContent = $LayoutObject->TicketListShow(
             FilterContentOnly   => 1,
             HeaderColumn        => $HeaderColumn,
             ElementChanged      => $ElementChanged,
             OriginalTicketIDs   => \@OriginalViewableTickets,
             Action              => 'AgentTicketStatusView',
             Env                 => $Self,
-            View                => $Self->{View},
+            View                => $View,
             EnableColumnFilters => 1,
         );
 
         if ( !$FilterContent ) {
-            $Self->{LayoutObject}->FatalError(
-                Message => "Can't get filter content data of $HeaderColumn!",
+            $LayoutObject->FatalError(
+                Message => $LayoutObject->{LanguageObject}
+                    ->Translate( 'Can\'t get filter content data of %s!', $HeaderColumn ),
             );
         }
 
-        return $Self->{LayoutObject}->Attachment(
-            ContentType => 'application/json; charset=' . $Self->{LayoutObject}->{Charset},
+        return $LayoutObject->Attachment(
+            ContentType => 'application/json; charset=' . $LayoutObject->{Charset},
             Content     => $FilterContent,
             Type        => 'inline',
             NoCache     => 1,
@@ -343,10 +313,10 @@ sub Run {
         my $StoredFilters = \%ColumnFilter;
 
         my $StoredFiltersKey = 'UserStoredFilterColumns-' . $Self->{Action};
-        $Self->{UserObject}->SetPreferences(
+        $UserObject->SetPreferences(
             UserID => $Self->{UserID},
             Key    => $StoredFiltersKey,
-            Value  => $Self->{JSONObject}->Encode( Data => $StoredFilters ),
+            Value  => $JSONObject->Encode( Data => $StoredFilters ),
         );
     }
 
@@ -356,22 +326,12 @@ sub Run {
 
     my %NavBarFilter;
     for my $Filter ( sort keys %Filters ) {
-        my $Count = $Self->{TicketObject}->TicketSearch(
+        my $Count = $TicketObject->TicketSearch(
             %{ $Filters{$Filter}->{Search} },
             %ColumnFilter,
             Result => 'COUNT',
         );
 
-        # prepare count for new article tickets
-        if ( $Filter eq 'New' ) {
-            my $CountAll = $Self->{TicketObject}->TicketSearch(
-                %{ $Filters{All}->{Search} },
-                %ColumnFilter,
-                Result => 'COUNT',
-            );
-            $Count = $CountAll - $Count;
-        }
-
         $NavBarFilter{ $Filters{$Filter}->{Prio} } = {
             Count  => $Count,
             Filter => $Filter,
@@ -386,28 +346,28 @@ sub Run {
         next COLUMNNAME if !$ColumnName;
         next COLUMNNAME if !$GetColumnFilter{$ColumnName};
         $ColumnFilterLink
-            .= ';' . $Self->{LayoutObject}->Ascii2Html( Text => 'ColumnFilter' . $ColumnName )
-            . '=' . $Self->{LayoutObject}->Ascii2Html( Text => $GetColumnFilter{$ColumnName} )
+            .= ';' . $LayoutObject->Ascii2Html( Text => 'ColumnFilter' . $ColumnName )
+            . '=' . $LayoutObject->Ascii2Html( Text => $GetColumnFilter{$ColumnName} )
     }
 
     # show ticket's
     my $LinkPage = 'Filter='
-        . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{Filter} )
-        . ';View=' . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{View} )
-        . ';SortBy=' . $Self->{LayoutObject}->Ascii2Html( Text => $SortBy )
-        . ';OrderBy=' . $Self->{LayoutObject}->Ascii2Html( Text => $OrderBy )
+        . $LayoutObject->Ascii2Html( Text => $Filter )
+        . ';View=' . $LayoutObject->Ascii2Html( Text => $View )
+        . ';SortBy=' . $LayoutObject->Ascii2Html( Text => $SortBy )
+        . ';OrderBy=' . $LayoutObject->Ascii2Html( Text => $OrderBy )
         . $ColumnFilterLink
         . ';';
     my $LinkSort = 'Filter='
-        . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{Filter} )
-        . ';View=' . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{View} )
+        . $LayoutObject->Ascii2Html( Text => $Filter )
+        . ';View=' . $LayoutObject->Ascii2Html( Text => $View )
         . $ColumnFilterLink
         . ';';
-    my $LinkFilter = 'SortBy=' . $Self->{LayoutObject}->Ascii2Html( Text => $SortBy )
-        . ';OrderBy=' . $Self->{LayoutObject}->Ascii2Html( Text => $OrderBy )
-        . ';View=' . $Self->{LayoutObject}->Ascii2Html( Text => $Self->{View} )
+    my $LinkFilter = 'SortBy=' . $LayoutObject->Ascii2Html( Text => $SortBy )
+        . ';OrderBy=' . $LayoutObject->Ascii2Html( Text => $OrderBy )
+        . ';View=' . $LayoutObject->Ascii2Html( Text => $View )
         . ';';
-    my $LastColumnFilter = $Self->{ParamObject}->GetParam( Param => 'LastColumnFilter' ) || '';
+    my $LastColumnFilter = $ParamObject->GetParam( Param => 'LastColumnFilter' ) || '';
 
     if ( !$LastColumnFilter && $ColumnFilterLink ) {
 
@@ -415,7 +375,7 @@ sub Run {
         $LastColumnFilter = 1;
     }
 
-    $Output .= $Self->{LayoutObject}->TicketListShow(
+    $Output .= $LayoutObject->TicketListShow(
         TicketIDs         => \@ViewableTickets,
         OriginalTicketIDs => \@OriginalViewableTickets,
         GetColumnFilter   => \%GetColumnFilter,
@@ -425,14 +385,14 @@ sub Run {
 
         Total => scalar @ViewableTickets,
 
-        View => $Self->{View},
+        View => $View,
 
-        Filter     => $Self->{Filter},
+        Filter     => $Filter,
         Filters    => \%NavBarFilter,
         FilterLink => $LinkFilter,
 
-        TitleName  => 'My Locked Tickets',
-        TitleValue => $Filters{ $Self->{Filter} }->{Name},
+        TitleName  => Translatable('My Locked Tickets'),
+        TitleValue => $Filters{$Filter}->{Name},
         Bulk       => 1,
 
         Env      => $Self,
@@ -443,12 +403,15 @@ sub Run {
         SortBy              => $SortBy,
         EnableColumnFilters => 1,
         ColumnFilterForm    => {
-            Filter => $Self->{Filter} || '',
+            Filter => $Filter || '',
         },
+
+        # do not print the result earlier, but return complete content
+        Output => 1,
     );
 
     # get page footer
-    $Output .= $Self->{LayoutObject}->Footer();
+    $Output .= $LayoutObject->Footer();
     return $Output;
 }
 
