@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,7 @@ use warnings;
 
 our $ObjectManagerDisabled = 1;
 
+use Kernel::Language qw(Translatable);
 use Kernel::System::VariableCheck qw(:all);
 
 sub new {
@@ -37,7 +38,7 @@ sub Run {
     # ------------------------------------------------------------ #
     if ( !$ConfigObject->Get('Ticket::Watcher') ) {
         return $LayoutObject->ErrorScreen(
-            Message => 'Feature is not active',
+            Message => Translatable('Feature is not active'),
         );
     }
 
@@ -163,7 +164,9 @@ sub Run {
         );
     }
 
-    $LayoutObject->ErrorScreen( Message => 'Invalid subaction' );
+    $LayoutObject->ErrorScreen(
+        Message => Translatable('Invalid Subaction.'),
+    );
 }
 
 1;
