@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +11,8 @@ package Kernel::Output::HTML::Dashboard::UserOnline;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our $ObjectManagerDisabled = 1;
 
 sub new {
@@ -85,7 +87,7 @@ sub Preferences {
 
     my @Params = (
         {
-            Desc  => 'Shown',
+            Desc  => Translatable('Shown'),
             Name  => $Self->{PrefKey},
             Block => 'Option',
             Data  => {
@@ -271,8 +273,8 @@ sub Run {
 
     # Check if agent has permission to start chats with the listed users
     my $EnableChat               = 1;
-    my $ChatStartingAgentsGroup  = $ConfigObject->Get('ChatEngine::PermissionGroup::ChatStartingAgents');
-    my $ChatReceivingAgentsGroup = $ConfigObject->Get('ChatEngine::PermissionGroup::ChatReceivingAgents');
+    my $ChatStartingAgentsGroup  = $ConfigObject->Get('ChatEngine::PermissionGroup::ChatStartingAgents') || 'users';
+    my $ChatReceivingAgentsGroup = $ConfigObject->Get('ChatEngine::PermissionGroup::ChatReceivingAgents') || 'users';
 
     if (
         !$ConfigObject->Get('ChatEngine::Active')
@@ -299,6 +301,21 @@ sub Run {
         $EnableChat = 0;
     }
 
+    my $VideoChatEnabled = 0;
+    my $VideoChatAgentsGroup = $ConfigObject->Get('ChatEngine::PermissionGroup::VideoChatAgents') || 'users';
+
+    # Enable the video chat feature if system is entitled and agent is a member of configured group.
+    if (
+        $ConfigObject->Get('ChatEngine::Active')
+        && defined $LayoutObject->{"UserIsGroup[$VideoChatAgentsGroup]"}
+        && $LayoutObject->{"UserIsGroup[$VideoChatAgentsGroup]"} eq 'Yes'
+        )
+    {
+        if ( $Kernel::OM->Get('Kernel::System::Main')->Require( 'Kernel::System::VideoChat', Silent => 1 ) ) {
+            $VideoChatEnabled = $Kernel::OM->Get('Kernel::System::VideoChat')->IsEnabled();
+        }
+    }
+
     USERID:
     for my $UserID ( sort { $OnlineUser{$a} cmp $OnlineUser{$b} } keys %OnlineUser ) {
 
@@ -309,13 +326,16 @@ sub Run {
         last USERID if $Count >= ( $Self->{StartHit} + $Self->{PageShown} );
 
         # extract user data
-        my $UserData        = $OnlineData{$UserID};
-        my $AgentEnableChat = 0;
-        my $ChatAccess      = 0;
+        my $UserData           = $OnlineData{$UserID};
+        my $AgentEnableChat    = 0;
+        my $CustomerEnableChat = 0;
+        my $ChatAccess         = 0;
+        my $VideoChatAvailable = 0;
+        my $VideoChatSupport   = 0;
 
         # Default status
-        my $UserState            = "Offline";
-        my $UserStateDescription = $LayoutObject->{LanguageObject}->Translate('This user is currently offline');
+        my $UserState            = Translatable('Offline');
+        my $UserStateDescription = $LayoutObject->{LanguageObject}->Translate('User is currently offline.');
 
         # we also need to check if the receiving agent has chat permissions
         if ( $EnableChat && $Self->{Filter} eq 'Agent' ) {
@@ -328,6 +348,11 @@ sub Run {
             my %UserGroupsReverse = reverse %UserGroups;
             $ChatAccess = $UserGroupsReverse{$ChatReceivingAgentsGroup} ? 1 : 0;
 
+            my %User = $Kernel::OM->Get('Kernel::System::User')->GetUserData(
+                UserID => $UserID,
+            );
+            $VideoChatSupport = $User{VideoChatHasWebRTC};
+
             # Check agents availability
             if ($ChatAccess) {
                 my $AgentChatAvailability = $Kernel::OM->Get('Kernel::System::Chat')->AgentAvailabilityGet(
@@ -336,22 +361,48 @@ sub Run {
                 );
 
                 if ( $AgentChatAvailability == 3 ) {
-                    $UserState            = "Active";
+                    $UserState            = Translatable('Active');
                     $AgentEnableChat      = 1;
-                    $UserStateDescription = $LayoutObject->{LanguageObject}->Translate('This user is currently active');
+                    $UserStateDescription = $LayoutObject->{LanguageObject}->Translate('User is currently active.');
+                    $VideoChatAvailable   = 1;
                 }
                 elsif ( $AgentChatAvailability == 2 ) {
-                    $UserState            = "Away";
-                    $AgentEnableChat      = 1;
-                    $UserStateDescription = $LayoutObject->{LanguageObject}->Translate('This user is currently away');
+                    $UserState       = Translatable('Away');
+                    $AgentEnableChat = 1;
+                    $UserStateDescription
+                        = $LayoutObject->{LanguageObject}->Translate('User was inactive for a while.');
                 }
                 elsif ( $AgentChatAvailability == 1 ) {
-                    $UserState = "Unavailable";
+                    $UserState = Translatable('Unavailable');
                     $UserStateDescription
-                        = $LayoutObject->{LanguageObject}->Translate('This user is currently unavailable');
+                        = $LayoutObject->{LanguageObject}->Translate('User set their status to unavailable.');
                 }
             }
         }
+        elsif ($EnableChat) {
+            $ChatAccess = 1;
+
+            my $CustomerChatAvailability = $Kernel::OM->Get('Kernel::System::Chat')->CustomerAvailabilityGet(
+                UserID => $UserData->{UserID},
+            );
+
+            my %CustomerUser = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerUserDataGet(
+                User => $UserID,
+            );
+            $VideoChatSupport = 1 if $CustomerUser{VideoChatHasWebRTC};
+
+            if ( $CustomerChatAvailability == 3 ) {
+                $UserState            = Translatable('Active');
+                $CustomerEnableChat   = 1;
+                $UserStateDescription = $LayoutObject->{LanguageObject}->Translate('User is currently active.');
+                $VideoChatAvailable   = 1;
+            }
+            elsif ( $CustomerChatAvailability == 2 ) {
+                $UserState            = Translatable('Away');
+                $CustomerEnableChat   = 1;
+                $UserStateDescription = $LayoutObject->{LanguageObject}->Translate('User was inactive for a while.');
+            }
+        }
 
         $LayoutObject->Block(
             Name => 'ContentSmallUserOnlineRow',
@@ -359,8 +410,12 @@ sub Run {
                 %{$UserData},
                 ChatAccess           => $ChatAccess,
                 AgentEnableChat      => $AgentEnableChat,
+                CustomerEnableChat   => $CustomerEnableChat,
                 UserState            => $UserState,
                 UserStateDescription => $UserStateDescription,
+                VideoChatEnabled     => $VideoChatEnabled,
+                VideoChatAvailable   => $VideoChatAvailable,
+                VideoChatSupport     => $VideoChatSupport,
             },
         );
 
