@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +11,8 @@ package Kernel::Output::HTML::Preferences::Password;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::Output::HTML::Layout',
@@ -60,21 +62,21 @@ sub Param {
         @Params,
         {
             %Param,
-            Key   => 'Current password',
+            Key   => Translatable('Current password'),
             Name  => 'CurPw',
             Raw   => 1,
             Block => 'Password'
         },
         {
             %Param,
-            Key   => 'New password',
+            Key   => Translatable('New password'),
             Name  => 'NewPw',
             Raw   => 1,
             Block => 'Password'
         },
         {
             %Param,
-            Key   => 'Verify password',
+            Key   => Translatable('Verify password'),
             Name  => 'NewPw1',
             Raw   => 1,
             Block => 'Password'
@@ -154,21 +156,19 @@ sub Run {
         )
         )
     {
-        $Self->{Error}
-            = $LayoutObject->{LanguageObject}->Translate('The current password is not correct. Please try again!');
+        $Self->{Error} = Translatable('The current password is not correct. Please try again!');
         return;
     }
 
     # check if pw is true
     if ( !$Pw || !$Pw1 ) {
-        $Self->{Error} = $LayoutObject->{LanguageObject}->Translate('Please supply your new password!');
+        $Self->{Error} = Translatable('Please supply your new password!');
         return;
     }
 
     # compare pws
     if ( $Pw ne $Pw1 ) {
-        $Self->{Error} = $LayoutObject->{LanguageObject}
-            ->Translate('Can\'t update password, your new passwords do not match. Please try again!');
+        $Self->{Error} = Translatable('Can\'t update password, your new passwords do not match. Please try again!');
         return;
     }
 
@@ -177,14 +177,13 @@ sub Run {
 
     # check if password is not matching PasswordRegExp
     if ( $Config->{PasswordRegExp} && $Pw !~ /$Config->{PasswordRegExp}/ ) {
-        $Self->{Error}
-            = $LayoutObject->{LanguageObject}->Translate('Can\'t update password, it contains invalid characters!');
+        $Self->{Error} = Translatable('Can\'t update password, it contains invalid characters!');
         return;
     }
 
     # check min size of password
     if ( $Config->{PasswordMinSize} && length $Pw < $Config->{PasswordMinSize} ) {
-        $Self->{Error} = $LayoutObject->{LanguageObject}->Translate(
+        $Self->{Error} = Translatable(
             'Can\'t update password, it must be at least %s characters long!',
             $Config->{PasswordMinSize}
         );
@@ -197,22 +196,20 @@ sub Run {
         && ( $Pw !~ /[A-Z].*[A-Z]/ || $Pw !~ /[a-z].*[a-z]/ )
         )
     {
-        $Self->{Error} = $LayoutObject->{LanguageObject}
-            ->Translate('Can\'t update password, it must contain at least 2 lowercase and 2 uppercase characters!');
+        $Self->{Error}
+            = Translatable('Can\'t update password, it must contain at least 2 lowercase and 2 uppercase characters!');
         return;
     }
 
     # check min 1 digit password
     if ( $Config->{PasswordNeedDigit} && $Pw !~ /\d/ ) {
-        $Self->{Error}
-            = $LayoutObject->{LanguageObject}->Translate('Can\'t update password, it must contain at least 1 digit!');
+        $Self->{Error} = Translatable('Can\'t update password, it must contain at least 1 digit!');
         return;
     }
 
     # check min 2 char password
     if ( $Config->{PasswordMin2Characters} && $Pw !~ /[A-z][A-z]/ ) {
-        $Self->{Error} = $LayoutObject->{LanguageObject}
-            ->Translate('Can\'t update password, it must contain at least 2 characters!');
+        $Self->{Error} = Translatable('Can\'t update password, it must contain at least 2 characters!');
         return;
     }
 
@@ -223,7 +220,7 @@ sub Run {
     );
     return if !$Success;
 
-    $Self->{Message} = 'Preferences updated successfully!';
+    $Self->{Message} = Translatable('Preferences updated successfully!');
     return 1;
 }
 
