@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -92,7 +92,7 @@ sub Run {
         ITEM:
         for my $Item (@Items) {
 
-            my ( $Permission, $Name ) = split /:/, $Item;
+            my ( $Permission, $Name ) = $Item =~ m{^([^:]+):(.*)$};
 
             if ( !$Permission || !$Name ) {
                 $LogObject->Log(
