@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
+use Kernel::Language qw(Translatable);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -87,7 +88,20 @@ sub new {
             Data => $Preferences{ $Self->{PrefKeyColumns} },
         );
 
-        @ColumnsEnabled = @{$ColumnsEnabled};
+        # remove duplicate columns
+        my %UniqueColumns;
+        my @ColumnsEnabledAux;
+
+        for my $Column ( @{$ColumnsEnabled} ) {
+            if ( !$UniqueColumns{$Column} ) {
+                push @ColumnsEnabledAux, $Column;
+            }
+            $UniqueColumns{$Column} = 1;
+        }
+
+        # set filtered column list
+        @ColumnsEnabled = @ColumnsEnabledAux;
+
     }
 
     # always set TicketNumber
@@ -120,12 +134,13 @@ sub new {
         FieldFilter => $Self->{DynamicFieldFilter} || {},
     );
 
-    # hash with all valid sortable columuns (taken from TicketSearch)
-    # SortBy  => 'Age',   # Owner|Responsible|CustomerID|State|TicketNumber|Queue
+    # hash with all valid sortable columns (taken from TicketSearch)
+    # SortBy  => 'Age',   # Created|Owner|Responsible|CustomerID|State|TicketNumber|Queue
     # |Priority|Type|Lock|Title|Service|Changed|SLA|PendingTime|EscalationTime
     # | EscalationUpdateTime|EscalationResponseTime|EscalationSolutionTime
     $Self->{ValidSortableColumns} = {
         'Age'                    => 1,
+        'Created'                => 1,
         'Owner'                  => 1,
         'Responsible'            => 1,
         'CustomerID'             => 1,
@@ -173,7 +188,7 @@ sub new {
     # get dynamic field backend object
     my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
 
-    # get filtrable dynamic fields
+    # get filterable dynamic fields
     # cycle trough the activated dynamic fields for this screen
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
@@ -184,7 +199,7 @@ sub new {
             Behavior           => 'IsFiltrable',
         );
 
-        # if the dynamic field is filtrable add it to the AvailableFilterableColumns hash
+        # if the dynamic field is filterable add it to the AvailableFilterableColumns hash
         if ($IsFiltrable) {
             $Self->{AvailableFilterableColumns}->{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = 1;
         }
@@ -249,7 +264,7 @@ sub ActionRow {
             Name => 'DocumentActionRowBulk',
             Data => {
                 %Param,
-                Name => 'Bulk',
+                Name => Translatable('Bulk'),
             },
         );
     }
@@ -640,7 +655,8 @@ sub Run {
                 }
 
                 # set title description
-                my $TitleDesc = $OrderBy eq 'Down' ? 'sorted descending' : 'sorted ascending';
+                my $TitleDesc
+                    = $OrderBy eq 'Down' ? Translatable('sorted descending') : Translatable('sorted ascending');
                 $TitleDesc = $LayoutObject->{LanguageObject}->Translate($TitleDesc);
                 $Title .= ', ' . $TitleDesc;
             }
@@ -687,9 +703,9 @@ sub Run {
             );
 
             $CSS = $Column;
-            my $Title = $Column;
+            my $Title = $LayoutObject->{LanguageObject}->Translate($Column);
 
-            # ouput overal block so TicketNumber as well as other columns can be ordered
+            # output overall block so TicketNumber as well as other columns can be ordered
             $LayoutObject->Block(
                 Name => 'OverviewNavBarPageTicketHeader',
                 Data => {},
@@ -708,7 +724,8 @@ sub Run {
                     }
 
                     # add title description
-                    my $TitleDesc = $OrderBy eq 'Down' ? 'sorted ascending' : 'sorted descending';
+                    my $TitleDesc
+                        = $OrderBy eq 'Down' ? Translatable('sorted ascending') : Translatable('sorted descending');
                     $TitleDesc = $LayoutObject->{LanguageObject}->Translate($TitleDesc);
                     $Title .= ', ' . $TitleDesc;
                 }
@@ -733,8 +750,8 @@ sub Run {
                     $TranslatedWord = $LayoutObject->{LanguageObject}->Translate($Column);
                 }
 
-                my $FilterTitle     = $Column;
-                my $FilterTitleDesc = 'filter not active';
+                my $FilterTitle     = $TranslatedWord;
+                my $FilterTitleDesc = Translatable('filter not active');
                 if (
                     $Self->{StoredFilters} &&
                     (
@@ -744,7 +761,7 @@ sub Run {
                     )
                 {
                     $CSS .= ' FilterActive';
-                    $FilterTitleDesc = 'filter active';
+                    $FilterTitleDesc = Translatable('filter active');
                 }
                 $FilterTitleDesc = $LayoutObject->{LanguageObject}->Translate($FilterTitleDesc);
                 $FilterTitle .= ', ' . $FilterTitleDesc;
@@ -827,7 +844,7 @@ sub Run {
                 # verify if column is filterable and sortable
                 elsif ( $Self->{ValidFilterableColumns}->{$Column} ) {
 
-                    # variable to save the filter's html code
+                    # variable to save the filter's HTML code
                     my $ColumnFilterHTML = $Self->_InitialColumnFilter(
                         ColumnName    => $Column,
                         Label         => $Column,
@@ -891,7 +908,8 @@ sub Run {
                     }
 
                     # add title description
-                    my $TitleDesc = $OrderBy eq 'Down' ? 'sorted ascending' : 'sorted descending';
+                    my $TitleDesc
+                        = $OrderBy eq 'Down' ? Translatable('sorted ascending') : Translatable('sorted descending');
                     $TitleDesc = $LayoutObject->{LanguageObject}->Translate($TitleDesc);
                     $Title .= ', ' . $TitleDesc;
                 }
@@ -917,11 +935,11 @@ sub Run {
                     $TranslatedWord = $LayoutObject->{LanguageObject}->Translate($Column);
                 }
 
-                my $FilterTitle     = $Column;
-                my $FilterTitleDesc = 'filter not active';
+                my $FilterTitle     = $TranslatedWord;
+                my $FilterTitleDesc = Translatable('filter not active');
                 if ( $Self->{StoredFilters} && $Self->{StoredFilters}->{ $Column . 'IDs' } ) {
                     $CSS .= ' FilterActive';
-                    $FilterTitleDesc = 'filter active';
+                    $FilterTitleDesc = Translatable('filter active');
                 }
                 $FilterTitleDesc = $LayoutObject->{LanguageObject}->Translate($FilterTitleDesc);
                 $FilterTitle .= ', ' . $FilterTitleDesc;
@@ -947,7 +965,7 @@ sub Run {
                         $Css .= ' Hidden';
                     }
 
-                    # variable to save the filter's html code
+                    # variable to save the filter's HTML code
                     my $ColumnFilterHTML = $Self->_InitialColumnFilter(
                         ColumnName    => $Column,
                         Label         => $Column,
@@ -992,7 +1010,7 @@ sub Run {
                         $Css = 'Hidden';
                     }
 
-                    # variable to save the filter's html code
+                    # variable to save the filter's HTML code
                     my $ColumnFilterHTML = $Self->_InitialColumnFilter(
                         ColumnName    => $Column,
                         Label         => $Column,
@@ -1099,15 +1117,16 @@ sub Run {
                         }
 
                         # add title description
-                        my $TitleDesc = $OrderBy eq 'Down' ? 'sorted ascending' : 'sorted descending';
+                        my $TitleDesc
+                            = $OrderBy eq 'Down' ? Translatable('sorted ascending') : Translatable('sorted descending');
                         $TitleDesc = $LayoutObject->{LanguageObject}->Translate($TitleDesc);
                         $Title .= ', ' . $TitleDesc;
                     }
 
-                    my $FilterTitleDesc = 'filter not active';
+                    my $FilterTitleDesc = Translatable('filter not active');
                     if ( $Self->{StoredFilters} && $Self->{StoredFilters}->{$Column} ) {
                         $CSS .= ' FilterActive';
-                        $FilterTitleDesc = 'filter active';
+                        $FilterTitleDesc = Translatable('filter active');
                     }
                     $FilterTitleDesc = $LayoutObject->{LanguageObject}->Translate($FilterTitleDesc);
                     $FilterTitle .= ', ' . $FilterTitleDesc;
@@ -1124,7 +1143,7 @@ sub Run {
 
                     if ( $Self->{ValidFilterableColumns}->{$DynamicFieldName} ) {
 
-                        # variable to save the filter's html code
+                        # variable to save the filter's HTML code
                         my $ColumnFilterHTML = $Self->_InitialColumnFilter(
                             ColumnName    => $DynamicFieldName,
                             Label         => $Label,
@@ -1171,7 +1190,7 @@ sub Run {
 
                     if ( $Self->{ValidFilterableColumns}->{$DynamicFieldName} ) {
 
-                        # variable to save the filter's html code
+                        # variable to save the filter's HTML code
                         my $ColumnFilterHTML = $Self->_InitialColumnFilter(
                             ColumnName    => $DynamicFieldName,
                             Label         => $Label,
@@ -1224,7 +1243,7 @@ sub Run {
 
                     if ( $Self->{ValidFilterableColumns}->{$DynamicFieldName} ) {
 
-                        # variable to save the filter's html code
+                        # variable to save the filter's HTML code
                         my $ColumnFilterHTML = $Self->_InitialColumnFilter(
                             ColumnName    => $DynamicFieldName,
                             Label         => $Label,
@@ -1265,7 +1284,7 @@ sub Run {
 
                     if ( $Self->{ValidFilterableColumns}->{$DynamicFieldName} ) {
 
-                        # variable to save the filter's html code
+                        # variable to save the filter's HTML code
                         my $ColumnFilterHTML = $Self->_InitialColumnFilter(
                             ColumnName    => $DynamicFieldName,
                             Label         => $Label,
@@ -1372,7 +1391,7 @@ sub Run {
                 Name => 'GeneralOverviewRow',
             );
             $LayoutObject->Block(
-                Name => 'Bulk',
+                Name => Translatable('Bulk'),
                 Data => { %Article, %UserInfo },
             );
         }
@@ -1661,7 +1680,7 @@ sub Run {
     );
 
     # set column filter form, to correctly fill the column filters is necessary to pass each
-    #    overview some information in the AJAX call, for examle the fixed Filters or NavBarFilters
+    #    overview some information in the AJAX call, for example the fixed Filters or NavBarFilters
     #    and also other values like the Queue in AgentTicketQueue, otherwise the filters will be
     #    filled with default restrictions, resulting in more options than the ones that the
     #    available tickets should provide, see Bug#9902
@@ -1857,7 +1876,7 @@ sub FilterContent {
         }
     }
 
-    # variable to save the filter's html code
+    # variable to save the filter's HTML code
     my $ColumnFilterJSON = $Self->_ColumnFilterJSON(
         ColumnName    => $HeaderColumn,
         Label         => $LabelColumn,
