@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -8,6 +8,8 @@
 
 package Kernel::Output::HTML::ToolBar::TicketService;
 
+use Kernel::Language qw(Translatable);
+
 use strict;
 use warnings;
 
@@ -93,7 +95,7 @@ sub Run {
     if ($Count) {
         $Return{ $Priority++ } = {
             Block       => 'ToolBarItem',
-            Description => 'Tickets in MyServices',
+            Description => Translatable('Tickets in My Services'),
             Count       => $Count,
             Class       => $Class,
             Icon        => $Icon,
