@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,7 @@ use strict;
 use warnings;
 
 use Net::LDAP;
+use Net::LDAP::Util qw(escape_filter_value);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -143,12 +144,8 @@ sub Sync {
         return;
     }
 
-    # user quote
-    my $UserQuote = $Param{User};
-    $UserQuote =~ s{ ( [\\()] ) }{\\$1}xmsg;
-
     # build filter
-    my $Filter = "($Self->{UID}=$UserQuote)";
+    my $Filter = "($Self->{UID}=" . escape_filter_value( $Param{User} ) . ')';
 
     # prepare filter
     if ( $Self->{AlwaysFilter} ) {
@@ -189,16 +186,15 @@ sub Sync {
         return;
     }
 
-    # DN quote
-    my $UserDNQuote = $UserDN;
-    $UserDNQuote =~ s{ ( [\\()] ) }{\\$1}xmsg;
-
     # get needed objects
     my $UserObject   = $Kernel::OM->Get('Kernel::System::User');
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
     # get current user id
-    my $UserID = $UserObject->UserLookup( UserLogin => $Param{User} );
+    my $UserID = $UserObject->UserLookup(
+        UserLogin => $Param{User},
+        Silent    => 1,
+    );
 
     # system permissions
     my %PermissionsEmpty =
@@ -370,10 +366,10 @@ sub Sync {
             # search if we are allowed to
             my $Filter;
             if ( $Self->{UserAttr} eq 'DN' ) {
-                $Filter = "($Self->{AccessAttr}=$UserDNQuote)";
+                $Filter = "($Self->{AccessAttr}=" . escape_filter_value($UserDN) . ')';
             }
             else {
-                $Filter = "($Self->{AccessAttr}=$UserQuote)";
+                $Filter = "($Self->{AccessAttr}=" . escape_filter_value( $Param{User} ) . ')';
             }
             my $Result = $LDAP->search(
                 base   => $GroupDN,
@@ -448,7 +444,7 @@ sub Sync {
     if ($UserSyncAttributeGroupsDefinition) {
 
         # build filter
-        my $Filter = "($Self->{UID}=$UserQuote)";
+        my $Filter = "($Self->{UID}=" . escape_filter_value( $Param{User} ) . ')';
 
         # perform search
         $Result = $LDAP->search(
@@ -522,9 +518,11 @@ sub Sync {
         }
     }
 
-    # compare group permissions from ldap with current user group permissions
+    # Compare group permissions from LDAP with current user group permissions.
     my %GroupPermissionsChanged;
+
     if (%GroupPermissionsFromLDAP) {
+
         PERMISSIONTYPE:
         for my $PermissionType ( @{ $ConfigObject->Get('System::Permission') } ) {
 
@@ -537,21 +535,19 @@ sub Sync {
             GROUPID:
             for my $GroupID ( sort keys %SystemGroups ) {
 
-                my $OldPermission = $GroupPermissions{$GroupID};
-                my $NewPermission = $GroupPermissionsFromLDAP{$GroupID}->{$PermissionType};
+                my $OldPermission = $GroupPermissions{$GroupID} ? 1 : 0;
 
-                # if old and new permission for group/type match, do nothing
-                if (
-                    ( $OldPermission && $NewPermission )
-                    ||
-                    ( !$OldPermission && !$NewPermission )
-                    )
-                {
-                    next GROUPID;
-                }
+                # Set the new permission (from LDAP) if exist, if not set it to a default value
+                #   regularly 0 but it LDAP has rw permission set it to 1 as PermissionUserGroupGet()
+                #   gets all system permissions to 1 if stored permission is rw.
+                my $NewPermission = $GroupPermissionsFromLDAP{$GroupID}->{$PermissionType}
+                    || $GroupPermissionsFromLDAP{$GroupID}->{rw} ? 1 : 0;
 
-                # permission for group/type differs - remember
-                $GroupPermissionsChanged{$GroupID}->{$PermissionType} = $NewPermission;
+                # Skip permission if is identical as in the DB
+                next GROUPID if $OldPermission == $NewPermission;
+
+                # Remember the LDAP permission if they are not identical as in the DB.
+                $GroupPermissionsChanged{$GroupID} = $GroupPermissionsFromLDAP{$GroupID};
             }
         }
     }
@@ -589,10 +585,10 @@ sub Sync {
             # search if we're allowed to
             my $Filter;
             if ( $Self->{UserAttr} eq 'DN' ) {
-                $Filter = "($Self->{AccessAttr}=$UserDNQuote)";
+                $Filter = "($Self->{AccessAttr}=" . escape_filter_value($UserDN) . ')';
             }
             else {
-                $Filter = "($Self->{AccessAttr}=$UserQuote)";
+                $Filter = "($Self->{AccessAttr}=" . escape_filter_value( $Param{User} ) . ')';
             }
             my $Result = $LDAP->search(
                 base   => $GroupDN,
@@ -655,7 +651,7 @@ sub Sync {
     if ($UserSyncAttributeRolesDefinition) {
 
         # build filter
-        my $Filter = "($Self->{UID}=$UserQuote)";
+        my $Filter = "($Self->{UID}=" . escape_filter_value( $Param{User} ) . ')';
 
         # perform search
         $Result = $LDAP->search(
