@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -34,80 +34,78 @@ sub Run {
 
     $Self->Print("<yellow>Process pending tickets...</yellow>\n");
 
-    my $StateObject = $Kernel::OM->Get('Kernel::System::State');
+    # get needed objects
+    my $StateObject  = $Kernel::OM->Get('Kernel::System::State');
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
+    my @TicketIDs;
 
     my @PendingAutoStateIDs = $StateObject->StateGetStatesByType(
         Type   => 'PendingAuto',
         Result => 'ID',
     );
 
-    if ( !@PendingAutoStateIDs ) {
-        $Self->Print(" No pending auto StateIDs found - skipping script!\n");
-        return $Self->ExitCodeOk();
-    }
+    if (@PendingAutoStateIDs) {
 
-    # get ticket object
-    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
-
-    # do ticket auto jobs
-    my @TicketIDs = $TicketObject->TicketSearch(
-        Result   => 'ARRAY',
-        StateIDs => [@PendingAutoStateIDs],
-        UserID   => 1,
-    );
-
-    my %States = %{ $Kernel::OM->Get('Kernel::Config')->Get('Ticket::StateAfterPending') };
-
-    TICKETID:
-    for my $TicketID (@TicketIDs) {
-
-        # get ticket data
-        my %Ticket = $TicketObject->TicketGet(
-            TicketID      => $TicketID,
-            UserID        => 1,
-            DynamicFields => 0,
-        );
-
-        next TICKETID if $Ticket{UntilTime} >= 1;
-
-        # error handling
-        if ( !$States{ $Ticket{State} } ) {
-            $Self->PrintError("No Ticket::StateAfterPending found for '$Ticket{State}' in Kernel/Config.pm!");
-            next TICKETID;
-        }
-
-        $Self->Print(
-            " Update ticket state for ticket $Ticket{TicketNumber} ($TicketID) to '$States{$Ticket{State}}'..."
-        );
-
-        # set new state
-        my $Success = $TicketObject->StateSet(
-            TicketID => $TicketID,
-            State    => $States{ $Ticket{State} },
+        # do ticket auto jobs
+        @TicketIDs = $TicketObject->TicketSearch(
+            Result   => 'ARRAY',
+            StateIDs => [@PendingAutoStateIDs],
             UserID   => 1,
         );
 
-        # error handling
-        if ( !$Success ) {
-            $Self->Print(" failed.\n");
-            next TICKETID;
-        }
+        my %States = %{ $Kernel::OM->Get('Kernel::Config')->Get('Ticket::StateAfterPending') };
 
-        # get state type for new state
-        my %State = $StateObject->StateGet(
-            Name => $States{ $Ticket{State} },
-        );
-        if ( $State{TypeName} eq 'closed' ) {
+        TICKETID:
+        for my $TicketID (@TicketIDs) {
 
-            # set new ticket lock
-            $TicketObject->LockSet(
-                TicketID     => $TicketID,
-                Lock         => 'unlock',
-                UserID       => 1,
-                Notification => 0,
+            # get ticket data
+            my %Ticket = $TicketObject->TicketGet(
+                TicketID      => $TicketID,
+                UserID        => 1,
+                DynamicFields => 0,
             );
+
+            next TICKETID if $Ticket{UntilTime} >= 1;
+            next TICKETID if !$States{ $Ticket{State} };
+
+            $Self->Print(
+                " Update ticket state for ticket $Ticket{TicketNumber} ($TicketID) to '$States{$Ticket{State}}'..."
+            );
+
+            # set new state
+            my $Success = $TicketObject->StateSet(
+                TicketID => $TicketID,
+                State    => $States{ $Ticket{State} },
+                UserID   => 1,
+            );
+
+            # error handling
+            if ( !$Success ) {
+                $Self->Print(" failed.\n");
+                next TICKETID;
+            }
+
+            # get state type for new state
+            my %State = $StateObject->StateGet(
+                Name => $States{ $Ticket{State} },
+            );
+            if ( $State{TypeName} eq 'closed' ) {
+
+                # set new ticket lock
+                $TicketObject->LockSet(
+                    TicketID     => $TicketID,
+                    Lock         => 'unlock',
+                    UserID       => 1,
+                    Notification => 0,
+                );
+            }
+            $Self->Print(" done.\n");
         }
-        $Self->Print(" done.\n");
+    }
+    else {
+
+        $Self->Print(" No pending auto StateIDs found!\n");
     }
 
     # do ticket reminder notification jobs
@@ -167,15 +165,3 @@ sub Run {
 }
 
 1;
-
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
