@@ -13,6 +13,11 @@ use warnings;
 
 use Authen::Radius;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -20,21 +25,19 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(LogObject ConfigObject DBObject)) {
-        $Self->{$_} = $Param{$_} || die "No $_!";
-    }
-
     # Debug 0=off 1=on
     $Self->{Debug} = 0;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # get config
-    $Self->{Die} = $Self->{ConfigObject}->Get( 'Customer::AuthModule::Radius::Die' . $Param{Count} );
+    $Self->{Die} = $ConfigObject->Get( 'Customer::AuthModule::Radius::Die' . $Param{Count} );
 
     # get user table
-    $Self->{RadiusHost} = $Self->{ConfigObject}->Get( 'Customer::AuthModule::Radius::Host' . $Param{Count} )
+    $Self->{RadiusHost} = $ConfigObject->Get( 'Customer::AuthModule::Radius::Host' . $Param{Count} )
         || die "Need Customer::AuthModule::Radius::Host$Param{Count} in Kernel/Config.pm";
-    $Self->{RadiusSecret} = $Self->{ConfigObject}->Get( 'Customer::AuthModule::Radius::Password' . $Param{Count} )
+    $Self->{RadiusSecret} = $ConfigObject->Get( 'Customer::AuthModule::Radius::Password' . $Param{Count} )
         || die "Need Customer::AuthModule::Radius::Password$Param{Count} in Kernel/Config.pm";
 
     return $Self;
@@ -45,7 +48,7 @@ sub GetOption {
 
     # check needed stuff
     if ( !$Param{What} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need What!"
         );
@@ -66,7 +69,7 @@ sub Auth {
 
     # check needed stuff
     if ( !$Param{User} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need User!"
         );
@@ -82,7 +85,7 @@ sub Auth {
 
     # just in case for debug!
     if ( $Self->{Debug} > 0 ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "User: '$User' tried to authenticate with Pw: '$Pw' ($RemoteAddr)",
         );
@@ -90,7 +93,7 @@ sub Auth {
 
     # just a note
     if ( !$User ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "No User given!!! (REMOTE_ADDR: $RemoteAddr)",
         );
@@ -99,7 +102,7 @@ sub Auth {
 
     # just a note
     if ( !$Pw ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "User: $User Authentication without Pw!!! (REMOTE_ADDR: $RemoteAddr)",
         );
@@ -116,7 +119,7 @@ sub Auth {
             die "Can't connect to $Self->{RadiusHost}: $@";
         }
         else {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't connect to $Self->{RadiusHost}: $@",
             );
@@ -127,7 +130,7 @@ sub Auth {
 
     # login note
     if ( defined($AuthResult) && $AuthResult == 1 ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "User: $User Authentication ok (REMOTE_ADDR: $RemoteAddr).",
         );
@@ -136,7 +139,7 @@ sub Auth {
 
     # just a note
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "User: $User Authentication with wrong Pw!!! (REMOTE_ADDR: $RemoteAddr)"
         );
