@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,6 +14,7 @@ use warnings;
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::Cache',
+    'Kernel::System::CustomerUser',
     'Kernel::System::DB',
     'Kernel::System::Group',
     'Kernel::System::Log',
@@ -199,6 +200,7 @@ sub GroupMemberList {
         Type => $Self->{CacheType},
         Key  => $CacheKey,
     );
+
     if ($Cache) {
         return @{$Cache} if ref $Cache eq 'ARRAY';
         return %{$Cache} if ref $Cache eq 'HASH';
@@ -234,23 +236,49 @@ sub GroupMemberList {
         else {
             $SQL .= " gu.group_id = " . $Self->{DBObject}->Quote( $Param{GroupID}, 'Integer', ) . "";
         }
+
         $Self->{DBObject}->Prepare( SQL => $SQL );
+
+        my @Values;
+
         while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
-            my $Key   = '';
-            my $Value = '';
             if ( $Param{UserID} ) {
-                $Key   = $Row[0];
-                $Value = $Row[1];
+                push @Values, {
+                    Users => {
+                        $Row[0] => $Row[1],
+                    },
+                };
             }
             else {
-                $Key   = $Row[4];
-                $Value = $Row[1];
+                push @Values, {
+                    CustomerUser => {
+                        $Row[4] => $Row[1],
+                    },
+                };
+            }
+        }
+
+        my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
+
+        KEY:
+        for my $Value (@Values) {
+
+            my ($UserType) = keys %{$Value};
+            my ($Login)    = keys %{ $Value->{$UserType} };
+
+            # Bugfix #12285 - Check if customer user is valid.
+            if ( $Param{GroupID} && $UserType eq 'CustomerUser' ) {
+
+                my %User = $CustomerUserObject->CustomerUserDataGet(
+                    User => $Login,
+                );
+
+                next KEY if defined $User{ValidID} && $User{ValidID} != 1;
             }
 
-            # get permissions
-            $Data{$Key} = $Value;
-            push @Name, $Value;
-            push @ID,   $Key;
+            $Data{$Login} = $Value->{$UserType}->{$Login};
+            push @Name, $Value->{$UserType}->{$Login};
+            push @ID,   $Login;
         }
     }
 
