@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -98,7 +98,9 @@ sub new {
     # create_by, change_time and change_by fields of OTRS
     $Self->{ForeignDB} = $Self->{CustomerUserMap}->{Params}->{ForeignDB} ? 1 : 0;
 
-    $Self->{CaseSensitive} = $Self->{CustomerUserMap}->{Params}->{CaseSensitive} || 0;
+    # defines if the database search will be performend case sensitive (1) or not (0)
+    $Self->{CaseSensitive} = $Self->{CustomerUserMap}->{Params}->{SearchCaseSensitive}
+        // $Self->{CustomerUserMap}->{Params}->{CaseSensitive} || 0;
 
     return $Self;
 }
@@ -1241,6 +1243,10 @@ sub _CustomerUserCacheClear {
         Type => $Self->{CacheType} . '_CustomerSearch',
     );
 
+    $Self->{CacheObject}->CleanUp(
+        Type => 'CustomerGroup',
+    );
+
     for my $Function (qw(CustomerUserList)) {
         for my $Valid ( 0 .. 1 ) {
             $Self->{CacheObject}->Delete(
