@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -745,7 +745,11 @@ sub Send {
 
     # set envelope sender for autoresponses and notifications
     if ( $Param{Loop} ) {
-        $RealFrom = $ConfigObject->Get('SendmailNotificationEnvelopeFrom') || '';
+        my $NotificationEnvelopeFrom = $ConfigObject->Get('SendmailNotificationEnvelopeFrom') || '';
+        my $NotificationFallback = $ConfigObject->Get('SendmailNotificationEnvelopeFrom::FallbackToEmailFrom');
+        if ( $NotificationEnvelopeFrom || !$NotificationFallback ) {
+            $RealFrom = $NotificationEnvelopeFrom;
+        }
     }
 
     # debug
