@@ -1,8 +1,5 @@
 # --
-# Kernel/System/EmailParser.pm - the global email parser module
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
-# --
-# $Id: EmailParser.pm,v 1.87 2009/07/18 09:19:06 martin Exp $
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,8 +11,6 @@ package Kernel::System::EmailParser;
 use strict;
 use warnings;
 
-use Kernel::System::HTMLUtils;
-
 use Mail::Internet;
 use MIME::Parser;
 use MIME::QuotedPrint;
@@ -23,16 +18,15 @@ use MIME::Base64;
 use MIME::Words qw(:all);
 use Mail::Address;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.87 $) [1];
+our $ObjectManagerDisabled = 1;
 
 =head1 NAME
 
-Kernel::System::EmailParser - parse and encode a email
+Kernel::System::EmailParser - parse and encode an email
 
 =head1 SYNOPSIS
 
-A module to parse and encode a email.
+A module to parse and encode an email.
 
 =head1 PUBLIC INTERFACE
 
@@ -42,26 +36,21 @@ A module to parse and encode a email.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
     use Kernel::System::EmailParser;
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
 
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
+    # as string (takes more memory!)
     my $ParserObject = Kernel::System::EmailParser->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-        EncodeObject => $EncodeObject,
-        Email        => \@ArrayOfEmail,
+        Email        => $EmailString,
+        Debug        => 0,
+    );
+
+    # as stand alone mode, without parsing emails
+    my $ParserObject = Kernel::System::EmailParser->new(
+        Mode         => 'Standalone',
         Debug        => 0,
     );
 
@@ -77,29 +66,48 @@ sub new {
     # get debug level from parent
     $Self->{Debug} = $Param{Debug} || 0;
 
-    # check needed objects
-    for (qw(LogObject ConfigObject EncodeObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    if ( $Param{Mode} && $Param{Mode} eq 'Standalone' ) {
+        return $Self;
     }
 
-    $Self->{HTMLUtilsObject} = Kernel::System::HTMLUtils->new(%Param);
-
     # check needed objects
     if ( !$Param{Email} && !$Param{Entity} ) {
         die "Need Email or Entity!";
     }
 
+    # if email is given
     if ( $Param{Email} ) {
 
+        # check if Email is an array ref
+        if ( ref $Param{Email} eq 'SCALAR' ) {
+            my @Content = split /\n/, ${ $Param{Email} };
+            for my $Line (@Content) {
+                $Line .= "\n";
+            }
+            $Param{Email} = \@Content;
+        }
+
+        # check if Email is an array ref
+        if ( ref $Param{Email} eq '' ) {
+            my @Content = split /\n/, $Param{Email};
+            for my $Line (@Content) {
+                $Line .= "\n";
+            }
+            $Param{Email} = \@Content;
+        }
+
         # create Mail::Internet object
         $Self->{Email} = Mail::Internet->new( $Param{Email} );
 
         # create a Mail::Header object with email
         $Self->{HeaderObject} = $Self->{Email}->head();
 
-        # create MIME::Parser object and get message body or body of first attachemnt
+        # create MIME::Parser object and get message body or body of first attachment
         my $Parser = MIME::Parser->new();
         $Parser->output_to_core('ALL');
+
+        # Keep nested messages as attachments (see bug#1970).
+        $Parser->extract_nested_messages(0);
         $Self->{ParserParts} = $Parser->parse_data( $Self->{Email}->as_string() );
     }
     else {
@@ -146,52 +154,47 @@ sub GetParam {
 
     my $What = $Param{WHAT} || return;
 
+    if ( !$Self->{Email} || !$Self->{HeaderObject} ) {
+
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Email and HeaderObject is needed!',
+        );
+        return;
+    }
+
     $Self->{HeaderObject}->unfold();
     $Self->{HeaderObject}->combine($What);
     my $Line = $Self->{HeaderObject}->get($What) || '';
     chomp($Line);
-    my $ReturnLine = '';
-    my %Remember   = ();
-    for my $Array ( decode_mimewords($Line) ) {
-        for ( @{$Array} ) {
+    my $ReturnLine;
 
-            # I don't know, but decode_mimewords() returns each mime
-            # word two times! Remember to the old one. :-(
-            if ( !$Remember{ $Array->[0] } ) {
-                if ( $Array->[0] && $Array->[1] ) {
-                    $Remember{ $Array->[0] } = 1;
-                }
-
-                # Workaround for OE problem:
-                # If a header contains =?iso-8859-1?Q?Fr=F6hlich=2C_Roman?=
-                # which is decoded ->Fröhlich, Roman<- which gets an problem
-                # because this means two email addresses. We add " at
-                # the start and at the end of this types of words mime.
-                if ( $What =~ /^(From|To|Cc)/ && $Array->[1] ) {
-                    if ( $Array->[0] !~ /^("|')/ && $Array->[0] =~ /,/ ) {
-                        $Array->[0] = '"' . $Array->[0] . '"';
-                        $Remember{ $Array->[0] } = 1;
-                    }
-                }
-                $ReturnLine .= $Self->{EncodeObject}->Decode(
-                    Text  => $Array->[0],
-                    From  => $Array->[1] || $Self->GetCharset() || 'us-ascii',
-                    Check => 1,
-                );
-            }
-            else {
-                $Remember{ $Array->[0] } = undef;
-            }
+    # We need to split address lists before decoding; see "6.2. Display of 'encoded-word's"
+    # in RFC 2047. Mail::Address routines will quote stuff if necessary (i.e. comma
+    # or semicolon found in phrase).
+    if ( $What =~ /^(From|To|Cc)/ ) {
+        for my $Address ( Mail::Address->parse($Line) ) {
+            $Address->phrase( $Self->_DecodeString( String => $Address->phrase() ) );
+            $Address->address( $Self->_DecodeString( String => $Address->address() ) );
+            $Address->comment( $Self->_DecodeString( String => $Address->comment() ) );
+            $ReturnLine .= ', ' if $ReturnLine;
+            $ReturnLine .= $Address->format();
         }
     }
+    else {
+        $ReturnLine = $Self->_DecodeString( String => $Line );
+    }
+
+    $ReturnLine //= '';
 
     # debug
     if ( $Self->{Debug} > 1 ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'debug',
             Message  => "Get: $What; ReturnLine: $ReturnLine; OrigLine: $Line",
         );
     }
+
     return $ReturnLine;
 }
 
@@ -209,12 +212,49 @@ sub GetEmailAddress {
     my ( $Self, %Param ) = @_;
 
     my $Email = '';
-    for my $EmailSplit ( Mail::Address->parse( $Param{Email} ) ) {
+    for my $EmailSplit ( $Self->_MailAddressParse( Email => $Param{Email} ) ) {
         $Email = $EmailSplit->address();
     }
+
+    # return if no email address is there
+    return if $Email !~ /@/;
+
+    # return email address
     return $Email;
 }
 
+=item GetRealname()
+
+To get the senders realname back.
+
+    my $Realname = $ParserObject->GetRealname(
+        Email => 'Juergen Weber <juergen.qeber@air.com>',
+    );
+
+=cut
+
+sub GetRealname {
+    my ( $Self, %Param ) = @_;
+    my $Realname = '';
+
+    # find "NamePart, NamePart" <some@example.com> (get not recognized by Mail::Address)
+    if ( $Param{Email} =~ /"(.+?)"\s+?\<.+?@.+?\..+?\>/ ) {
+        $Realname = $1;
+
+        # removes unnecessary blank spaces, if the string has quotes.
+        # This is because of bug 6059
+        $Realname =~ s/"\s+?(.+?)\s+?"/"$1"/g;
+        return $Realname;
+    }
+
+    # fallback of Mail::Address
+    for my $EmailSplit ( $Self->_MailAddressParse( Email => $Param{Email} ) ) {
+        $Realname = $EmailSplit->phrase();
+    }
+
+    return $Realname;
+}
+
 =item SplitAddressLine()
 
 To get an array of email addresses of an To, Cc or Bcc line back.
@@ -230,10 +270,11 @@ This returns an array with ('Juergen Weber <juergen.qeber@air.com>', 'me@example
 sub SplitAddressLine {
     my ( $Self, %Param ) = @_;
 
-    my @GetParam = ();
-    for my $Line ( Mail::Address->parse( $Param{Line} ) ) {
+    my @GetParam;
+    for my $Line ( $Self->_MailAddressParse( Email => $Param{Line} ) ) {
         push @GetParam, $Line->format();
     }
+
     return @GetParam;
 }
 
@@ -273,7 +314,7 @@ sub GetCharset {
 
         # debug
         if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message  => "Got charset from mime body: $Self->{Charset}",
             );
@@ -281,9 +322,17 @@ sub GetCharset {
         return $Self->{Charset};
     }
 
+    if ( !$Self->{Email} || !$Self->{HeaderObject} ) {
+
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Email and HeaderObject is needed!',
+        );
+        return;
+    }
+
     # find charset
     $Self->{HeaderObject}->unfold();
-    $Self->{HeaderObject}->combine('Content-Type');
     my $Line = $Self->{HeaderObject}->get('Content-Type') || '';
     chomp $Line;
     my %Data = $Self->GetContentTypeParams( ContentType => $Line );
@@ -295,14 +344,14 @@ sub GetCharset {
 
         # debug
         if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message =>
                     "Got no charset from email body because of ContentType ($Data{ContentType})!",
             );
         }
 
-        # remember to charset
+        # remember charset
         $Self->{Charset} = '';
 
         # return charset
@@ -314,13 +363,13 @@ sub GetCharset {
 
         # debug
         if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message  => "Got charset from email body: $Data{Charset}",
             );
         }
 
-        # remember to charset
+        # remember charset
         $Self->{Charset} = $Data{Charset};
 
         # return charset
@@ -332,13 +381,13 @@ sub GetCharset {
 
     # debug
     if ( $Self->{Debug} > 0 ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'debug',
             Message  => 'Got no charset from email body! Take iso-8859-1!',
         );
     }
 
-    # remember to charset
+    # remember charset
     $Self->{Charset} = 'ISO-8859-1';
 
     # return charset
@@ -360,27 +409,15 @@ sub GetReturnContentType {
     my $Self = shift;
 
     my $ContentType = $Self->GetContentType();
-    if ( $Self->{EncodeObject}->EncodeInternalUsed() ) {
-        my $InternalCharset = $Self->{EncodeObject}->EncodeInternalUsed();
-        $ContentType =~ s/(charset=)(.*)/$1$InternalCharset/ig;
-
-        # debug
-        if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
-                Priority => 'debug',
-                Message  => "Changed ContentType from '"
-                    . $Self->GetContentType()
-                    . "' to '$ContentType'.",
-            );
-        }
-        return $ContentType;
-    }
+    $ContentType =~ s/(charset=)(.*)/$1utf-8/ig;
 
     # debug
     if ( $Self->{Debug} > 0 ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'debug',
-            Message  => 'Changed no ContentType',
+            Message  => "Changed ContentType from '"
+                . $Self->GetContentType()
+                . "' to '$ContentType'.",
         );
     }
     return $ContentType;
@@ -400,11 +437,7 @@ Returns the charset of the new message body "Charset"
 sub GetReturnCharset {
     my $Self = shift;
 
-    if ( $Self->{EncodeObject}->EncodeInternalUsed() ) {
-        return $Self->{EncodeObject}->EncodeInternalUsed();
-    }
-
-    return $Self->GetCharset();
+    return 'utf-8';
 }
 
 =item GetMessageBody()
@@ -421,10 +454,13 @@ sub GetMessageBody {
     # check if message body is already there
     return $Self->{MessageBody} if $Self->{MessageBody};
 
+    # get encode object
+    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+
     if ( !$Self->{EntityMode} && $Self->{ParserParts}->parts() == 0 ) {
         $Self->{MimeEmail} = 0;
         if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message  => 'It\'s a plain (not mime) email!',
             );
@@ -436,14 +472,14 @@ sub GetMessageBody {
             $BodyStrg = MIME::QuotedPrint::decode($BodyStrg);
         }
 
-        # base 64 encode
+        # base64 decode
         elsif ( $Self->GetParam( WHAT => 'Content-Transfer-Encoding' ) =~ /base64/i ) {
             $BodyStrg = decode_base64($BodyStrg);
         }
 
         # charset decode
         if ( $Self->GetCharset() ) {
-            $Self->{MessageBody} = $Self->{EncodeObject}->Decode(
+            $Self->{MessageBody} = $EncodeObject->Convert2CharsetInternal(
                 Text  => $BodyStrg,
                 From  => $Self->GetCharset(),
                 Check => 1,
@@ -453,7 +489,7 @@ sub GetMessageBody {
             $Self->{MessageBody} = $BodyStrg;
         }
 
-        # check if it's juat a html email (store it as attachment and add text/plain)
+        # check if the mail contains only HTML (store it as attachment and add text/plain)
         $Self->CheckMessageBody();
 
         # return message body
@@ -462,20 +498,22 @@ sub GetMessageBody {
     else {
         $Self->{MimeEmail} = 1;
         if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message  => 'It\'s a mime email!',
             );
         }
 
-        # check if there is an valid attachment there, if yes, return
-        # first attachment (normally text/plain) as message body
+        # Check if there is a valid attachment there, if yes, return
+        #   the first attachment (normally text/plain) as message body.
+        # For multipart/mixed emails, PartsAttachments() will concatenate subsequent
+        #   body MIME parts into just one attachment.
         my @Attachments = $Self->GetAttachments();
         if ( @Attachments > 0 ) {
             $Self->{Charset}     = $Attachments[0]->{Charset};
             $Self->{ContentType} = $Attachments[0]->{ContentType};
             if ( $Self->{Debug} > 0 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message  => "First attachment ContentType: $Self->{ContentType}",
                 );
@@ -488,7 +526,7 @@ sub GetMessageBody {
 
             # check if charset exists
             if ( $Self->GetCharset() ) {
-                $Self->{MessageBody} = $Self->{EncodeObject}->Decode(
+                $Self->{MessageBody} = $EncodeObject->Convert2CharsetInternal(
                     Text  => $Attachments[0]->{Content},
                     From  => $Self->GetCharset(),
                     Check => 1,
@@ -500,7 +538,7 @@ sub GetMessageBody {
                 $Self->{MessageBody} = '- no text message => see attachment -';
             }
 
-            # check it it's juat a html email (store it as attachment and add text/plain)
+            # check if it's a html-only email (store it as attachment and add text/plain)
             $Self->CheckMessageBody();
 
             # return message body
@@ -508,10 +546,10 @@ sub GetMessageBody {
         }
         else {
             if ( $Self->{Debug} > 0 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message =>
-                        'No attachments returned from GetAttachments(), just a null attachment!?',
+                        'No attachments returned from GetAttachments(), just an empty attachment!?',
                 );
             }
 
@@ -521,6 +559,7 @@ sub GetMessageBody {
             return '-';
         }
     }
+
     return;
 }
 
@@ -539,6 +578,7 @@ Returns an array of the email attachments.
         # optional
         print $Attachment->{ContentID};
         print $Attachment->{ContentAlternative};
+        print $Attachment->{ContentMixed};
     }
 
 =cut
@@ -549,13 +589,13 @@ sub GetAttachments {
     # return if it's no mime email
     return if !$Self->{MimeEmail};
 
-    # return if it got already parsed
+    # return if it is already parsed
     return @{ $Self->{Attachments} } if $Self->{Attachments};
 
     # parse email
     $Self->PartsAttachments( Part => $Self->{ParserParts} );
 
-    # return if no attachments got found
+    # return if no attachments are found
     return if !$Self->{Attachments};
 
     # return attachments
@@ -570,17 +610,20 @@ sub PartsAttachments {
     my $PartCounter        = $Param{PartCounter}        || 0;
     my $SubPartCounter     = $Param{SubPartCounter}     || 0;
     my $ContentAlternative = $Param{ContentAlternative} || '';
+    my $ContentMixed       = $Param{ContentMixed}       || '';
     $Self->{PartCounter}++;
     if ( $Part->parts() > 0 ) {
 
         # check if it's an alternative part
-        my $ContentAlternative;
         $Part->head()->unfold();
         $Part->head()->combine('Content-Type');
         my $ContentType = $Part->head()->get('Content-Type');
         if ( $ContentType && $ContentType =~ /multipart\/alternative;/i ) {
             $ContentAlternative = 1;
         }
+        if ( $ContentType && $ContentType =~ /multipart\/mixed;/i ) {
+            $ContentMixed = 1;
+        }
         $PartCounter++;
         for my $Part ( $Part->parts() ) {
             $SubPartCounter++;
@@ -591,15 +634,15 @@ sub PartsAttachments {
                 Part               => $Part,
                 PartCounter        => $PartCounter,
                 ContentAlternative => $ContentAlternative,
+                ContentMixed       => $ContentMixed,
             );
         }
         return 1;
     }
 
     # get attachment meta stuff
-    my %PartData = ();
+    my %PartData;
 
-    # get content alternative
     if ($ContentAlternative) {
         $PartData{ContentAlternative} = $ContentAlternative;
     }
@@ -628,7 +671,7 @@ sub PartsAttachments {
     if ( $Part->bodyhandle() ) {
         $PartData{Content} = $Part->bodyhandle()->as_string();
         if ( !$PartData{Content} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'notice',
                 Message  => "Totally empty attachment part ($PartCounter)",
             );
@@ -638,7 +681,7 @@ sub PartsAttachments {
 
     # log error if there is an corrupt MIME email
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message =>
                 "Was not able to parse corrupt MIME email! Skipped attachment ($PartCounter)",
@@ -646,13 +689,12 @@ sub PartsAttachments {
         return;
     }
 
-    # check if there is no recommended_filename -> add file-NoFilenamePartCounter
-    if ( !$Part->head()->recommended_filename() ) {
-        $Self->{NoFilenamePartCounter}++;
-        $PartData{Filename} = "file-$Self->{NoFilenamePartCounter}";
-    }
-    else {
-        $PartData{Filename}           = decode_mimewords( $Part->head()->recommended_filename() );
+    # check if there is no recommended_filename or subject -> add file-NoFilenamePartCounter
+    if ( $Part->head()->recommended_filename() ) {
+        $PartData{Filename} = $Self->_DecodeString(
+            String => $Part->head()->recommended_filename(),
+            Encode => 'utf-8',
+        );
         $PartData{ContentDisposition} = $Part->head()->get('Content-Disposition');
         if ( $PartData{ContentDisposition} ) {
             my %Data = $Self->GetContentTypeParams(
@@ -666,35 +708,112 @@ sub PartsAttachments {
             $PartData{Charset} = '';
         }
 
-        # convert the file name in utf-8 if utf-8 is used
-        if ( $PartData{Charset} ) {
-            $PartData{Filename} = $Self->{EncodeObject}->Decode(
-                Text  => $PartData{Filename},
-                From  => $PartData{Charset},
-                Check => 1,
-            );
+        # check if reserved filename file-1 or file-2 is already used
+        COUNT:
+        for my $Count ( 1 .. 2 ) {
+            if ( $PartData{Filename} eq "file-$Count" ) {
+                $PartData{Filename} = "File-$Count";
+                last COUNT;
+            }
         }
     }
 
-    # parse/get Content-Id for html email attachments
-    $PartData{ContentID} = $Part->head()->get('Content-Id');
+    # Guess the filename for nested messages (see bug#1970).
+    elsif ( $PartData{ContentType} eq 'message/rfc822' ) {
+
+        my ($SubjectString) = $Part->as_string() =~ m/^Subject: ([^\n]*(\n[ \t][^\n]*)*)/m;
+        my $Subject = $Self->_DecodeString( String => $SubjectString );
+
+        # trim whitespace
+        $Subject =~ s/^\s+|\n|\s+$//g;
+        if ( length($Subject) > 246 ) {
+            $Subject = substr( $Subject, 0, 246 );
+        }
+
+        if ( $Subject eq '' ) {
+            $Self->{NoFilenamePartCounter}++;
+            $Subject = "Unbenannt-$Self->{NoFilenamePartCounter}";
+        }
+        $PartData{Filename} = $Subject . '.eml';
+    }
+    else {
+        $Self->{NoFilenamePartCounter}++;
+        $PartData{Filename} = "file-$Self->{NoFilenamePartCounter}";
+    }
+
+    # parse/get Content-Id, Content-Location and Disposition for html email attachments
+    $PartData{ContentID}       = $Part->head()->get('Content-Id');
+    $PartData{ContentLocation} = $Part->head()->get('Content-Location');
+    $PartData{Disposition}     = $Part->head()->get('Content-Disposition');
+
     if ( $PartData{ContentID} ) {
         chomp $PartData{ContentID};
     }
-
-    # debug
-    if ( $Self->{Debug} > 0 ) {
-        print STDERR "->GotArticle::Atm: '$PartData{Filename}' '$PartData{ContentType}'\n";
+    elsif ( $PartData{ContentLocation} ) {
+        chomp $PartData{ContentLocation};
+        $PartData{ContentID} = $PartData{ContentLocation};
+    }
+    if ( $PartData{Disposition} ) {
+        chomp $PartData{Disposition};
+        $PartData{Disposition} = lc $PartData{Disposition}
     }
 
     # get attachment size
+    $PartData{Filesize} = bytes::length( $PartData{Content} );
+
+    # debug
+    if ( $Self->{Debug} > 0 ) {
+        print STDERR
+            "->GotArticle::Atm: '$PartData{Filename}' '$PartData{ContentType}' ($PartData{Filesize})\n";
+    }
+
+    # For multipart/mixed emails, we check for all text/plain or text/html MIME parts which are
+    #   body elements, and concatenate them into the first relevant attachment, to stay in line
+    #   with OTRS file-1 and file-2 attachment handling.
+    # HTML parts will just be concatenated, so that the attachment has two complete HTML documents
+    #   inside. Browsers tolerate this.
+    if (
+        $ContentMixed
+        && ( !$PartData{Disposition} || $PartData{Disposition} eq 'inline' )
+        && ( $PartData{ContentType} =~ /text\/(?:html|plain)/i )
+        )
     {
-        use bytes;
-        $PartData{Filesize} = length $PartData{Content};
-        no bytes;
+        # Is it a plain or HTML body?
+        my $MimeType = $PartData{ContentType} =~ /text\/html/i ? 'text/html' : 'text/plain';
+        my $AttachmentKey = 'AttachmentFor_' . $MimeType;
+
+        # For concatenating multipart/mixed text parts, we have to convert all of them to utf-8 to be sure that
+        #   the contents fit together and that all characters can be displayed.
+        $PartData{Content} = $Kernel::OM->Get('Kernel::System::Encode')->Convert2CharsetInternal(
+            Text  => $PartData{Content},
+            From  => $PartData{Charset},
+            Check => 1,
+        );
+        $PartData{ContentType} = "$MimeType; charset=utf-8";
+        my $OldCharset = $PartData{Charset};
+        $PartData{Charset} = "utf-8";
+
+        # Also replace charset in meta tags of HTML emails.
+        if ( $MimeType eq 'text/html' ) {
+            $PartData{Content} =~ s/(<meta[^>]+charset=("|'|))\Q$OldCharset\E/$1utf-8/gi;
+        }
+
+        $PartData{Filesize} = bytes::length( $PartData{Content} );
+
+        # Is it the first body element found? Then remember it.
+        if ( !$Self->{$AttachmentKey} ) {
+            $Self->{$AttachmentKey} = \%PartData;
+        }
+
+        # Is it a subsequent body element? Then concatenate it to the first one and skip it as attachment.
+        else {
+            # This concatenation only works if all parts have the utf-8 flag on (from Convert2CharsetInternal).
+            $Self->{$AttachmentKey}->{Content} .= $PartData{Content};
+            $Self->{$AttachmentKey}->{Filesize} += $PartData{Filesize};
+            return 1;    # Don't create an attachment for this part.
+        }
     }
 
-    # store data
     push @{ $Self->{Attachments} }, \%PartData;
     return 1;
 }
@@ -744,11 +863,11 @@ sub GetContentTypeParams {
     my ( $Self, %Param ) = @_;
 
     my $ContentType = $Param{ContentType} || return;
-    if ( $Param{ContentType} =~ /charset=.+?/i ) {
+    if ( $Param{ContentType} =~ /charset\s*=.+?/i ) {
         $Param{Charset} = $Param{ContentType};
-        $Param{Charset} =~ s/.+?charset=("|'|)(\w+)/$2/gi;
+        $Param{Charset} =~ s/.*?charset\s*=\s*(.*?)/$1/i;
         $Param{Charset} =~ s/"|'//g;
-        $Param{Charset} =~ s/(.+?);.*/$1/g;
+        $Param{Charset} =~ s/(.+?)(;|\s).*/$1/g;
     }
     if ( !$Param{Charset} ) {
         if (
@@ -769,7 +888,7 @@ sub GetContentTypeParams {
             $Param{Charset} = $1;
         }
     }
-    if ( $Param{ContentType} =~ /^(\w+\/\w+)/i ) {
+    if ( $Param{ContentType} =~ /Content-Type:\s{0,1}(.+?\/.+?)(;|'|"|\s)/i ) {
         $Param{MimeType} = $1;
         $Param{MimeType} =~ s/"|'//g;
     }
@@ -784,12 +903,12 @@ sub CheckMessageBody {
     return if $Self->{MessageChecked};
 
     # return if no auto convert from html2text is needed
-    return if !$Self->{ConfigObject}->Get('PostmasterAutoHTML2Text');
+    return if !$Kernel::OM->Get('Kernel::Config')->Get('PostmasterAutoHTML2Text');
 
     # return if no auto convert from html2text is needed
     return if $Self->{NoHTMLChecks};
 
-    # check it it's juat a html email (store it as attachment and add text/plain)
+    # check if it's just a html email (store it as attachment and add text/plain)
     if ( $Self->GetReturnContentType() =~ /text\/html/i ) {
         $Self->{MessageChecked} = 1;
 
@@ -806,7 +925,7 @@ sub CheckMessageBody {
             );
         }
 
-        # remember to html file if not aleady there
+        # add .html suffix to filename if not aleady there
         else {
             if ( $Self->{Attachments}->[0]->{Filename} ) {
                 if ( $Self->{Attachments}->[0]->{Filename} !~ /\.(htm|html)/i ) {
@@ -815,40 +934,123 @@ sub CheckMessageBody {
             }
         }
 
-        # remember to be an mime email now
+        # remember to be a mime email now
         $Self->{MimeEmail} = 1;
 
         # convert from html to ascii
-        $Self->{MessageBody} = $Self->{HTMLUtilsObject}->ToAscii(
+        $Self->{MessageBody} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToAscii(
             String => $Self->{MessageBody},
         );
 
         $Self->{ContentType} = 'text/plain';
         if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message =>
                     'It\'s an html only email, added ascii dump, attached html email as attachment.',
             );
         }
     }
+
     return;
 }
 
-1;
+=begin Internal:
+
+=item _DecodeString()
+
+Decode all encoded substrings.
+
+    my $Result = $Self->_DecodeString(
+        String => 'some text',
+    );
+
+=cut
+
+sub _DecodeString {
+    my ( $Self, %Param ) = @_;
+
+    # get encode object
+    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+
+    my $DecodedString;
+    my $BufferedString;
+    my $PrevEncoding;
+
+    $BufferedString = '';
+
+    # call MIME::Words::decode_mimewords()
+    for my $Entry ( decode_mimewords( $Param{String} ) ) {
+        if (
+            $BufferedString ne ''
+            && ( !$PrevEncoding || !$Entry->[1] || lc($PrevEncoding) ne lc( $Entry->[1] ) )
+            )
+        {
+            my $Encoding = $EncodeObject->FindAsciiSupersetEncoding(
+                Encodings => [ $PrevEncoding, $Param{Encode}, $Self->GetCharset() ],
+            );
+            $DecodedString .= $EncodeObject->Convert2CharsetInternal(
+                Text  => $BufferedString,
+                From  => $Encoding,
+                Check => 1,
+            );
+            $BufferedString = '';
+        }
+        $BufferedString .= $Entry->[0];
+        $PrevEncoding = $Entry->[1];
+    }
+
+    if ( $BufferedString ne '' ) {
+        my $Encoding = $EncodeObject->FindAsciiSupersetEncoding(
+            Encodings => [ $PrevEncoding, $Param{Encode}, $Self->GetCharset() ],
+        );
+        $DecodedString .= $EncodeObject->Convert2CharsetInternal(
+            Text  => $BufferedString,
+            From  => $Encoding,
+            Check => 1,
+        );
+    }
+
+    return $DecodedString;
+}
+
+=item _MailAddressParse()
+
+    my @Chunks = $ParserObject->_MailAddressParse(Email => $Email);
+
+Wrapper for C<Mail::Address->parse($Email)>, but cache it, since it's
+not too fast, and often called.
+
+=cut
+
+sub _MailAddressParse {
+    my ( $Self, %Param ) = @_;
+
+    my $Email = $Param{Email};
+    my $Cache = $Self->{EmailCache};
+
+    if ( $Self->{EmailCache}->{$Email} ) {
+        return @{ $Self->{EmailCache}->{$Email} };
+    }
+
+    my @Chunks = Mail::Address->parse($Email);
+    $Self->{EmailCache}->{$Email} = \@Chunks;
+
+    return @Chunks;
+}
+
+=end Internal:
 
 =back
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
-
-=head1 VERSION
-
-$Revision: 1.87 $ $Date: 2009/07/18 09:19:06 $
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+1;
