@@ -18,8 +18,12 @@ use File::stat;
 use Unicode::Normalize;
 use List::Util qw();
 use Storable;
+use Fcntl qw(:flock);
 
-use Kernel::System::Encode;
+our @ObjectDependencies = (
+    'Kernel::System::Encode',
+    'Kernel::System::Log',
+);
 
 =head1 NAME
 
@@ -37,26 +41,11 @@ All main functions to load modules, die, and handle files.
 
 =item new()
 
-create new object
+create new object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
 =cut
 
@@ -67,18 +56,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for my $Object (qw(ConfigObject LogObject)) {
-        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
-    }
-
-    # get or create encode object
-    $Self->{EncodeObject} = $Param{EncodeObject};
-    $Self->{EncodeObject} ||= Kernel::System::Encode->new( %{$Self} );
-
-    # set debug mode
-    $Self->{Debug} = $Param{Debug} || 0;
-
     return $Self;
 }
 
@@ -97,7 +74,7 @@ sub Require {
     my ( $Self, $Module, %Param ) = @_;
 
     if ( !$Module ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need module!',
         );
@@ -130,10 +107,11 @@ sub Require {
     if ($@) {
 
         if ( !$Param{Silent} ) {
-            $Self->{LogObject}->Log(
+            my $Message = $@;
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Caller   => 1,
                 Priority => 'error',
-                Message  => "$@",
+                Message  => $Message,
             );
         }
 
@@ -144,10 +122,18 @@ sub Require {
     if ( !$Result ) {
 
         if ( !$Param{Silent} ) {
-            $Self->{LogObject}->Log(
+            my $Message = "Module $Module not found/could not be loaded";
+            if ( !-f $File ) {
+                $Message = "Module $Module not in \@INC (@INC)";
+            }
+            elsif ( !-r $File ) {
+                $Message = "Module could not be loaded (no read permissions on $File)";
+            }
+
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Caller   => 1,
                 Priority => 'error',
-                Message  => "Module $Module not found/could not be loaded!",
+                Message  => $Message,
             );
         }
 
@@ -157,14 +143,6 @@ sub Require {
     # add module
     $INC{$Module} = $File;
 
-    # log debug message
-    if ( $Self->{Debug} > 1 ) {
-        $Self->{LogObject}->Log(
-            Priority => 'debug',
-            Message  => "Module: $Module loaded!",
-        );
-    }
-
     return 1;
 }
 
@@ -214,7 +192,7 @@ sub Die {
     $Message = $Message || 'Died!';
 
     # log message
-    $Self->{LogObject}->Log(
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
         Caller   => 1,
         Priority => 'error',
         Message  => $Message,
@@ -243,20 +221,22 @@ sub FilenameCleanUp {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{Filename} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Filename!',
         );
         return;
     }
 
-    if ( $Param{Type} && $Param{Type} =~ /^md5/i ) {
-        $Self->{EncodeObject}->EncodeOutput( \$Param{Filename} );
+    my $Type = lc( $Param{Type} || 'local' );
+
+    if ( $Type eq 'md5' ) {
+        $Kernel::OM->Get('Kernel::System::Encode')->EncodeOutput( \$Param{Filename} );
         $Param{Filename} = md5_hex( $Param{Filename} );
     }
 
     # replace invalid token for attachment file names
-    elsif ( $Param{Type} && $Param{Type} =~ /^attachment/i ) {
+    elsif ( $Type eq 'attachment' ) {
 
         # replace invalid token like < > ? " : ; | \ / or *
         $Param{Filename} =~ s/[ <>\?":\\\*\|\/;\[\]]/_/g;
@@ -294,26 +274,26 @@ sub FilenameCleanUp {
 to read files from file system
 
     my $ContentSCALARRef = $MainObject->FileRead(
-        Directory => 'c:\some\location\me_to',
-        Filename  => 'alal.xml',
+        Directory => 'c:\some\location',
+        Filename  => 'file2read.txt',
         # or Location
-        Location  => 'c:\some\location\me_to\alal.xml'
+        Location  => 'c:\some\location\file2read.txt',
     );
 
     my $ContentARRAYRef = $MainObject->FileRead(
-        Directory => 'c:\some\location\me_to',
-        Filename  => 'alal.xml',
+        Directory => 'c:\some\location',
+        Filename  => 'file2read.txt',
         # or Location
-        Location  => 'c:\some\location\me_to\alal.xml'
+        Location  => 'c:\some\location\file2read.txt',
 
         Result    => 'ARRAY', # optional - SCALAR|ARRAY
     );
 
     my $ContentSCALARRef = $MainObject->FileRead(
-        Directory       => 'c:\some\location\me_to',
-        Filename        => 'alal.xml',
+        Directory       => 'c:\some\location',
+        Filename        => 'file2read.txt',
         # or Location
-        Location        => 'c:\some\location\me_to\alal.xml'
+        Location        => 'c:\some\location\file2read.txt',
 
         Mode            => 'binmode', # optional - binmode|utf8
         Type            => 'Local',   # optional - Local|Attachment|MD5
@@ -342,7 +322,7 @@ sub FileRead {
         $Param{Location} =~ s{//}{/}xmsg;
     }
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Filename and Directory or Location!',
         );
@@ -352,7 +332,7 @@ sub FileRead {
     # check if file exists
     if ( !-e $Param{Location} ) {
         if ( !$Param{DisableWarnings} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "File '$Param{Location}' doesn't exist!"
             );
@@ -369,7 +349,7 @@ sub FileRead {
     # return if file can not open
     if ( !open $FH, $Mode, $Param{Location} ) {    ## no critic
         if ( !$Param{DisableWarnings} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't open '$Param{Location}': $!",
             );
@@ -378,9 +358,9 @@ sub FileRead {
     }
 
     # lock file (Shared Lock)
-    if ( !flock $FH, 1 ) {
+    if ( !flock $FH, LOCK_SH ) {
         if ( !$Param{DisableWarnings} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't lock '$Param{Location}': $!",
             );
@@ -415,23 +395,23 @@ to write data to file system
 
     my $FileLocation = $MainObject->FileWrite(
         Directory => 'c:\some\location',
-        Filename  => 'me_to/alal.xml',
+        Filename  => 'file2write.txt',
         # or Location
-        Location  => 'c:\some\location\me_to\alal.xml'
+        Location  => 'c:\some\location\file2write.txt',
 
         Content   => \$Content,
     );
 
     my $FileLocation = $MainObject->FileWrite(
         Directory  => 'c:\some\location',
-        Filename   => 'me_to/alal.xml',
+        Filename   => 'file2write.txt',
         # or Location
-        Location   => 'c:\some\location\me_to\alal.xml'
+        Location   => 'c:\some\location\file2write.txt',
 
         Content    => \$Content,
         Mode       => 'binmode', # binmode|utf8
         Type       => 'Local',   # optional - Local|Attachment|MD5
-        Permission => '644',     # unix file permissions
+        Permission => '644',     # optional - unix file permissions
     );
 
 Platform note: MacOS (HFS+) stores filenames as Unicode NFD internally,
@@ -457,7 +437,7 @@ sub FileWrite {
         $Param{Location} =~ s/\/\//\//g;
     }
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Filename and Directory or Location!',
         );
@@ -482,7 +462,7 @@ sub FileWrite {
     # return if file can not open
     my $FH;
     if ( !open $FH, $Mode, $Param{Location} ) {    ## no critic
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't write '$Param{Location}': $!",
         );
@@ -490,8 +470,8 @@ sub FileWrite {
     }
 
     # lock file (Exclusive Lock)
-    if ( !flock $FH, 2 ) {
-        $Self->{LogObject}->Log(
+    if ( !flock $FH, LOCK_EX ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't lock '$Param{Location}': $!",
         );
@@ -504,7 +484,7 @@ sub FileWrite {
     if ( !$Param{Mode} || lc $Param{Mode} eq 'binmode' ) {
 
         # make sure, that no utf8 stamp exists (otherway perl will do auto convert to iso)
-        $Self->{EncodeObject}->EncodeOutput( $Param{Content} );
+        $Kernel::OM->Get('Kernel::System::Encode')->EncodeOutput( $Param{Content} );
 
         # set file handle to binmode
         binmode $FH;
@@ -569,7 +549,7 @@ sub FileDelete {
         $Param{Location} =~ s/\/\//\//g;
     }
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Filename and Directory or Location!',
         );
@@ -578,7 +558,7 @@ sub FileDelete {
     # check if file exists
     if ( !-e $Param{Location} ) {
         if ( !$Param{DisableWarnings} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "File '$Param{Location}' doesn't exist!"
             );
@@ -589,7 +569,7 @@ sub FileDelete {
     # delete file
     if ( !unlink( $Param{Location} ) ) {
         if ( !$Param{DisableWarnings} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't delete '$Param{Location}': $!",
             );
@@ -632,7 +612,7 @@ sub FileGetMTime {
         $Param{Location} =~ s{//}{/}xmsg;
     }
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Filename and Directory or Location!',
         );
@@ -642,7 +622,7 @@ sub FileGetMTime {
     # check if file exists
     if ( !-e $Param{Location} ) {
         if ( !$Param{DisableWarnings} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "File '$Param{Location}' doesn't exist!"
             );
@@ -654,7 +634,7 @@ sub FileGetMTime {
     my $Stat = stat( $Param{Location} );
 
     if ( !$Stat ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Cannot stat file '$Param{Location}': $!"
         );
@@ -687,7 +667,7 @@ sub MD5sum {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{Filename} && !$Param{String} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Filename or String!',
         );
@@ -696,7 +676,7 @@ sub MD5sum {
 
     # check if file exists
     if ( $Param{Filename} && !-e $Param{Filename} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "File '$Param{Filename}' doesn't exist!",
         );
@@ -709,7 +689,7 @@ sub MD5sum {
         # open file
         my $FH;
         if ( !open $FH, '<', $Param{Filename} ) {    ## no critic
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't read '$Param{Filename}': $!",
             );
@@ -723,19 +703,22 @@ sub MD5sum {
         return $MD5sum;
     }
 
+    # get encode object
+    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+
     # md5sum string
     if ( !ref $Param{String} ) {
-        $Self->{EncodeObject}->EncodeOutput( \$Param{String} );
+        $EncodeObject->EncodeOutput( \$Param{String} );
         return md5_hex( $Param{String} );
     }
 
     # md5sum scalar reference
     if ( ref $Param{String} eq 'SCALAR' ) {
-        $Self->{EncodeObject}->EncodeOutput( $Param{String} );
+        $EncodeObject->EncodeOutput( $Param{String} );
         return md5_hex( ${ $Param{String} } );
     }
 
-    $Self->{LogObject}->Log(
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
         Priority => 'error',
         Message  => "Need a SCALAR reference like 'String => \$Content' in String param.",
     );
@@ -771,7 +754,7 @@ sub Dump {
 
     # check needed data
     if ( !defined $Data ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need \$String in Dump()!"
         );
@@ -783,7 +766,7 @@ sub Dump {
         $Type = 'binary';
     }
     if ( $Type ne 'ascii' && $Type ne 'binary' ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Invalid Type '$Type'!"
         );
@@ -876,7 +859,7 @@ sub DirectoryRead {
     # check needed params
     for my $Needed (qw(Directory Filter)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Message  => "Needed $Needed: $!",
                 Priority => 'error',
             );
@@ -886,7 +869,7 @@ sub DirectoryRead {
 
     # if directory doesn't exists stop
     if ( !-d $Param{Directory} && !$Param{Silent} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Message  => "Directory doesn't exist: $Param{Directory}: $!",
             Priority => 'error',
         );
@@ -895,7 +878,7 @@ sub DirectoryRead {
 
     # check Filter param
     if ( ref $Param{Filter} ne '' && ref $Param{Filter} ne 'ARRAY' ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Message  => 'Filter param need to be scalar or array ref!',
             Priority => 'error',
         );
@@ -915,9 +898,10 @@ sub DirectoryRead {
         my @Glob = glob "$Param{Directory}/$Filter";
 
         # look for repeated values
+        NAME:
         for my $GlobName (@Glob) {
 
-            next if !-e $GlobName;
+            next NAME if !-e $GlobName;
             if ( !$Seen{$GlobName} ) {
                 push @GlobResults, $GlobName;
                 $Seen{$GlobName} = 1;
@@ -929,14 +913,16 @@ sub DirectoryRead {
 
         # loop protection to prevent symlinks causing lockups
         $Param{LoopProtection}++;
-        last if $Param{LoopProtection} > 100;
+        return if $Param{LoopProtection} > 100;
 
         # check all files in current directory
         my @Directories = glob "$Param{Directory}/*";
+
+        DIRECTORY:
         for my $Directory (@Directories) {
 
             # return if file is not a directory
-            next if !-d $Directory;
+            next DIRECTORY if !-d $Directory;
 
             # repeat same glob for directory
             my @SubResult = $Self->DirectoryRead(
@@ -957,12 +943,15 @@ sub DirectoryRead {
     # if no results
     return if !@GlobResults;
 
+    # get encode object
+    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+
     # compose normalize every name in the file list
     my @Results;
     for my $Filename (@GlobResults) {
 
         # first convert filename to utf-8 if utf-8 is used internally
-        $Filename = $Self->{EncodeObject}->Convert2CharsetInternal(
+        $Filename = $EncodeObject->Convert2CharsetInternal(
             Text => $Filename,
             From => 'utf-8',
         );
@@ -972,13 +961,13 @@ sub DirectoryRead {
 
     # always sort the result
     @Results = sort @Results;
-    return @Results;
 
+    return @Results;
 }
 
 =item GenerateRandomString()
 
-generate a random string of defined lenght, and of a defined alphabet.
+generate a random string of defined length, and of a defined alphabet.
 defaults to a length of 16 and alphanumerics ( 0..9, A-Z and a-z).
 
     my $String = $MainObject->GenerateRandomString();
@@ -1073,13 +1062,13 @@ sub _Dump {
 
             my $KeyNew = $Key;
 
-            # check for changed keys
             $Self->_Dump( \$KeyNew );
 
-            next KEY if $Key eq $KeyNew;
+            if ( $Key ne $KeyNew ) {
 
-            ${$Data}->{$KeyNew} = ${$Data}->{$Key};
-            delete ${$Data}->{$Key};
+                ${$Data}->{$KeyNew} = ${$Data}->{$Key};
+                delete ${$Data}->{$Key};
+            }
         }
 
         return;
@@ -1107,7 +1096,7 @@ sub _Dump {
         return;
     }
 
-    $Self->{LogObject}->Log(
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
         Priority => 'error',
         Message  => "Unknown ref '" . ref( ${$Data} ) . "'!",
     );
