@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -32,6 +32,9 @@ my $NoConnectWarningPeriod = 60 * 60 * 24 * 5;    # 5 days
 # If we cannot connect to cloud.otrs.com for more than the second period, show an error.
 my $NoConnectErrorPeriod = 60 * 60 * 24 * 15;     # 15 days
 
+# If we cannot connect to cloud.otrs.com for more than the second period, block the system.
+my $NoConnectBlockPeriod = 60 * 60 * 24 * 25;     # 25 days
+
 # If the contract is about to expire in less than this time, show a hint
 my $ContractExpiryWarningPeriod = 60 * 60 * 24 * 28;    # 28 days
 
@@ -67,13 +70,19 @@ sub new {
 
     #$Self->{APIVersion} = 1;
 
+    # Get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # Get OTRSBusiness::ReleaseChannel from SysConfig (Stable = 1, Development = 0)
-    $Self->{OnlyStable} = $Kernel::OM->Get('Kernel::Config')->Get('OTRSBusiness::ReleaseChannel') // 1;
+    $Self->{OnlyStable} = $ConfigObject->Get('OTRSBusiness::ReleaseChannel') // 1;
 
     # Set cache params
     $Self->{CacheType} = 'OTRSBusiness';
     $Self->{CacheTTL}  = 60 * 60 * 24 * 30;    # 30 days
 
+    # Check if cloud services are disabled
+    $Self->{CloudServicesDisabled} = $ConfigObject->Get('CloudServices::Disabled') || 0;
+
     return $Self;
 }
 
@@ -123,6 +132,8 @@ checks with cloud.otrs.com if OTRSBusiness is available for the current framewor
 sub OTRSBusinessIsAvailable {
     my ( $Self, %Param ) = @_;
 
+    return if $Self->{CloudServicesDisabled};
+
     my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
     my $RequestResult      = $CloudServiceObject->Request(
         RequestData => {
@@ -251,6 +262,8 @@ system_data table for offline usage.
 sub OTRSBusinessIsUpdateable {
     my ( $Self, %Param ) = @_;
 
+    return 0 if $Self->{CloudServicesDisabled};
+
     my $Package = $Self->_GetOTRSBusinessPackageFromRepository();
     return if !$Package;
 
@@ -385,6 +398,8 @@ Returns 1 if the cloud call was successful.
 sub OTRSBusinessEntitlementCheck {
     my ( $Self, %Param ) = @_;
 
+    return if $Self->{CloudServicesDisabled};
+
     my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
     my $RequestResult      = $CloudServiceObject->Request(
         RequestData => {
@@ -444,12 +459,13 @@ sub OTRSBusinessEntitlementCheck {
 Returns the current entitlement status.
 
     my $Status = $OTRSBusinessObject->OTRSBusinessEntitlementStatus(
-        CallCloudService => 1,  # 0 or 1, call the cloud service before looking at the cache
+        CallCloudService => 1,              # 0 or 1, call the cloud service before looking at the cache
     );
 
-    $Status = 'entitled';   # everything is OK
-    $Status = 'warning';    # last check was OK, and we are in the waiting period
-    $Status = 'forbidden';  # not entitled (either because the server said so or because the last check was too long ago)
+    $Status = 'entitled';      # everything is OK
+    $Status = 'warning';       # last check was OK, and we are in the waiting period - show warning
+    $Status = 'warning-error'; # last check was OK, and we are past waiting period - show error message
+    $Status = 'forbidden';     # not entitled (either because the server said so or because the last check was too long ago)
 
 =cut
 
@@ -487,9 +503,12 @@ sub OTRSBusinessEntitlementStatus {
 
     my $SecondsSinceLastUpdate = $Kernel::OM->Get('Kernel::System::Time')->SystemTime() - $LastUpdateSystemTime;
 
-    if ( $SecondsSinceLastUpdate > $NoConnectErrorPeriod ) {
+    if ( $SecondsSinceLastUpdate > $NoConnectBlockPeriod ) {
         return 'forbidden';
     }
+    if ( $SecondsSinceLastUpdate > $NoConnectErrorPeriod ) {
+        return 'warning-error';
+    }
     if ( $SecondsSinceLastUpdate > $NoConnectWarningPeriod ) {
         return 'warning';
     }
@@ -556,11 +575,16 @@ sub HandleBusinessPermissionCloudServiceResult {
         LastUpdateTime     => $Kernel::OM->Get('Kernel::System::Time')->SystemTime2TimeStamp(
             SystemTime => $Kernel::OM->Get('Kernel::System::Time')->SystemTime()
         ),
+        AgentSessionLimit             => $OperationResult->{Data}->{AgentSessionLimit},
+        AgentSessionLimitPriorWarning => $OperationResult->{Data}->{AgentSessionLimitPriorWarning},
     );
 
     my $SystemDataObject = $Kernel::OM->Get('Kernel::System::SystemData');
 
+    KEY:
     for my $Key ( sort keys %StoreData ) {
+        next KEY if !defined $StoreData{$Key};
+
         my $FullKey = 'OTRSBusiness::' . $Key;
 
         if ( defined $SystemDataObject->SystemDataGet( Key => $FullKey ) ) {
@@ -621,6 +645,8 @@ sub HandleBusinessVersionCheckCloudServiceResult {
 sub _OTRSBusinessFileGet {
     my ( $Self, %Param ) = @_;
 
+    return if $Self->{CloudServicesDisabled};
+
     my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
     my $RequestResult      = $CloudServiceObject->Request(
         RequestData => {
