@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -71,7 +71,7 @@ sub Run {
         }
 
         # match 'Match => ???' stuff
-        my $Matched       = '';
+        my $Matched       = 0;    # Numbers are required because of the bitwise or in the negation.
         my $MatchedNot    = 0;
         my $MatchedResult = '';
         for ( sort keys %Match ) {
