@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -33,10 +33,9 @@ sub Run {
 
     my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
-    # The first attachment in a MIME email in OTRS is currently the body,
-    #   so ignore it for this follow up check.
+    # Ignore all inline parts as these are actually part of the email body.
     my @Attachments = $Self->{ParserObject}->GetAttachments();
-    shift @Attachments;
+    @Attachments = grep { defined $_->{ContentDisposition} && $_->{ContentDisposition} ne 'inline' } @Attachments;
 
     ATTACHMENT:
     for my $Attachment (@Attachments) {
