@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -25,6 +25,7 @@ our @ObjectDependencies = (
     'Kernel::System::State',
     'Kernel::System::Ticket',
     'Kernel::System::Time',
+    'Kernel::System::User',
 );
 
 =head1 NAME
@@ -81,7 +82,7 @@ sub new {
             State         => 'new',              # or StateID => 5,
             CustomerID    => '123465',
             CustomerUser  => 'customer@example.com',
-            OwnerID       => 123,
+            Owner         => 'someuserlogin',    # or OwnerID => 123
 
             # ticket optional:
             TN              => $TicketObject->TicketCreateNumber(), # optional
@@ -196,6 +197,13 @@ sub Run {
         }
     }
 
+    # Get OwnerID from Owner
+    if ( $TicketParam{Owner} && !$TicketParam{OwnerID} ) {
+        $TicketParam{OwnerID} = $Kernel::OM->Get('Kernel::System::User')->UserLookup(
+            UserLogin => $TicketParam{Owner},
+        );
+    }
+
     # get ticket object
     my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
