@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -183,7 +183,7 @@ to add a template to a queue
     my $Success = $QueueObject->QueueStandardTemplateMemberAdd(
         QueueID            => 123,
         StandardTemplateID => 123,
-        Active             => 1,        # optional
+        Active             => 1,        # to set/confirm (1) or remove (0) the relation
         UserID             => 123,
     );
 
