@@ -1,6 +1,5 @@
 # --
-# Kernel/System/Stats/Static/StateAction.pm - static stat for ticket history
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -94,7 +93,6 @@ sub Run {
     my @PossibleStates;
     for my $StateID ( sort { $States{$a} cmp $States{$b} } keys %States ) {
         $States{$StateID} = $LanguageObject->Translate( $States{$StateID} );
-        $States{$StateID} =~ s/^(.{18}).*$/$1\.\.\./;
         push @PossibleStates, $States{$StateID};
     }
 
