@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -104,7 +104,6 @@ collect system data
 sub Collect {
     my ( $Self, %Param ) = @_;
 
-    # check cache
     my $CacheKey = 'DataCollect';
 
     if ( $Param{UseCache} ) {
@@ -116,37 +115,54 @@ sub Collect {
     }
 
     # Data must be collected in a web request context to be able to collect web server data.
-    #   If called from CLI, make a web request to collect the data.
+    #   If called from CLI, make a web request to collect the data, but if the data couldn't
+    #   be collected the function runs normal.
     if ( !$ENV{GATEWAY_INTERFACE} ) {
-        return $Self->CollectByWebRequest(%Param);
+
+        my %ResultWebRequest = $Self->CollectByWebRequest(%Param);
+
+        return %ResultWebRequest if $ResultWebRequest{Success};
     }
 
-    # Look for all plug-ins in the FS
+    # Get the disabled plugins from the config to generate a lookup hash, which can be used to skip these plugins.
+    my $PluginDisabled = $Kernel::OM->Get('Kernel::Config')->Get('SupportDataCollector::DisablePlugins') || [];
+    my %LookupPluginDisabled = map { $_ => 1 } @{$PluginDisabled};
+
+    # Get the identifier filter blacklist from the config to generate a lookup hash, which can be used to
+    # filter these identifier.
+    my $IdentifierFilterBlacklist
+        = $Kernel::OM->Get('Kernel::Config')->Get('SupportDataCollector::IdentifierFilterBlacklist') || [];
+    my %LookupIdentifierFilterBlacklist = map { $_ => 1 } @{$IdentifierFilterBlacklist};
+
+    # Look for all plug-ins in the FS.
     my @PluginFiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
         Directory => dirname(__FILE__) . "/SupportDataCollector/Plugin",
         Filter    => "*.pm",
         Recursive => 1,
     );
 
-    # Look for all asynchronous plug-ins in the FS
+    # Look for all asynchronous plug-ins in the FS.
     my @PluginAsynchronousFiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
         Directory => dirname(__FILE__) . "/SupportDataCollector/PluginAsynchronous",
         Filter    => "*.pm",
         Recursive => 1,
     );
 
-    # merge the both plug-ins types together
+    # Merge the both plug-in types together.
     my @PluginFilesAll = ( @PluginFiles, @PluginAsynchronousFiles );
 
     my @Result;
 
-    # Execute all plug-ins
+    # Execute all plug-ins.
+    PLUGINFILE:
     for my $PluginFile (@PluginFilesAll) {
 
         # Convert file name => package name
         $PluginFile =~ s{^.*(Kernel/System.*)[.]pm$}{$1}xmsg;
         $PluginFile =~ s{/+}{::}xmsg;
 
+        next PLUGINFILE if $LookupPluginDisabled{$PluginFile};
+
         if ( !$Kernel::OM->Get('Kernel::System::Main')->Require($PluginFile) ) {
             return (
                 Success      => 0,
@@ -159,16 +175,19 @@ sub Collect {
 
         if ( !%PluginResult || !$PluginResult{Success} ) {
             return (
-                Success => 0,
-                ErrorMessage =>
-                    "Error during execution of $PluginFile: $PluginResult{ErrorMessage}",
+                Success      => 0,
+                ErrorMessage => "Error during execution of $PluginFile: $PluginResult{ErrorMessage}",
             );
         }
 
         push @Result, @{ $PluginResult{Result} // [] };
     }
 
-    # sort the results from the plug-ins by the short identifier
+    # Remove the disabled plugins after the execution, because some plugins returns
+    #   more information with a own identifier.
+    @Result = grep { !$LookupIdentifierFilterBlacklist{ $_->{Identifier} } } @Result;
+
+    # Sort the results from the plug-ins by the short identifier.
     @Result = sort { $a->{ShortIdentifier} cmp $b->{ShortIdentifier} } @Result;
 
     my %ReturnData = (
@@ -176,13 +195,17 @@ sub Collect {
         Result  => \@Result,
     );
 
-    # set cache
-    $Kernel::OM->Get('Kernel::System::Cache')->Set(
-        Type  => 'SupportDataCollector',
-        Key   => $CacheKey,
-        Value => \%ReturnData,
-        TTL   => 60 * 10,
-    );
+    # Cache the result only, if the support data were collected in a web request,
+    #   to have all support data in the admin view.
+    if ( $ENV{GATEWAY_INTERFACE} ) {
+
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type  => 'SupportDataCollector',
+            Key   => $CacheKey,
+            Value => \%ReturnData,
+            TTL   => 60 * 10,
+        );
+    }
 
     return %ReturnData;
 }
@@ -194,7 +217,7 @@ sub CollectByWebRequest {
     #   PublicSupportDataCollector requires this ChallengeToken.
     my $ChallengeToken = $Kernel::OM->Get('Kernel::System::Main')->GenerateRandomString(
         Length     => 32,
-        Dictionary => [ 0 .. 9, 'a' .. 'f' ],    # hexadecimal
+        Dictionary => [ 0 .. 9, 'a' .. 'f' ],    # Generate a hexadecimal value.
     );
 
     if (
@@ -216,8 +239,8 @@ sub CollectByWebRequest {
     }
 
     my $Host = $Param{Hostname};
+    $Host ||= $Kernel::OM->Get('Kernel::Config')->Get('SupportDataCollector::HTTPHostname');
 
-    # Determine hostname
     if ( !$Host ) {
         my $FQDN = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
 
@@ -232,9 +255,9 @@ sub CollectByWebRequest {
         $Host ||= '127.0.0.1';
     }
 
-    # if the public interface is proteceted with .htaccess
-    # we can specify the htaccess login data here,
-    # this is neccessary for the support data collector
+    # If the public interface is proteceted with .htaccess
+    #   we can specify the htaccess login data here,
+    #   this is neccessary for the support data collector.
     my $AuthString   = '';
     my $AuthUser     = $Kernel::OM->Get('Kernel::Config')->Get('PublicFrontend::AuthUser');
     my $AuthPassword = $Kernel::OM->Get('Kernel::Config')->Get('PublicFrontend::AuthPassword');
@@ -242,7 +265,7 @@ sub CollectByWebRequest {
         $AuthString = $AuthUser . ':' . $AuthPassword . '@';
     }
 
-    # prepare web service config
+    # Prepare web service config for the internal web request.
     my $URL =
         $Kernel::OM->Get('Kernel::Config')->Get('HttpType')
         . '://'
@@ -252,20 +275,18 @@ sub CollectByWebRequest {
         . $Kernel::OM->Get('Kernel::Config')->Get('ScriptAlias')
         . 'public.pl';
 
-    # create webuseragent object
     my $WebUserAgentObject = Kernel::System::WebUserAgent->new(
         Timeout => $Param{WebTimeout} || 20,
     );
 
-    # disable webuseragent proxy since the call is sent to self server, see bug#11680
+    # Disable webuseragent proxy since the call is sent to self server, see bug#11680.
     $WebUserAgentObject->{Proxy} = '';
 
-    # define result
     my %Result = (
         Success => 0,
     );
 
-    # skip the ssl verification, because this is only a internal web request
+    # Skip the ssl verification, because this is only a internal web request.
     my %Response = $WebUserAgentObject->Request(
         Type => 'POST',
         URL  => $URL,
@@ -276,24 +297,27 @@ sub CollectByWebRequest {
         SkipSSLVerification => 1,
     );
 
-    # test if the web response was successful
     if ( $Response{Status} ne '200 OK' ) {
-        $Result{ErrorMessage} = "Can't connect to server - $Response{Status}";
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'notice',
-            Message  => "SupportDataCollector - $Result{ErrorMessage}",
-        );
+
+        if ( $Self->{Debug} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'notice',
+                Message  => "SupportDataCollector - Can't connect to server - $Response{Status}",
+            );
+        }
 
         return %Result;
     }
 
     # check if we have content as a scalar ref
     if ( !$Response{Content} || ref $Response{Content} ne 'SCALAR' ) {
-        $Result{ErrorMessage} = 'No content received.';
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'notice',
-            Message  => "SupportDataCollector - $Result{ErrorMessage}",
-        );
+
+        if ( $Self->{Debug} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'notice',
+                Message  => "SupportDataCollector - No content received.",
+            );
+        }
         return %Result;
     }
 
@@ -302,11 +326,14 @@ sub CollectByWebRequest {
 
     # Discard HTML responses (error pages etc.).
     if ( substr( ${ $Response{Content} }, 0, 1 ) eq '<' ) {
-        $Result{ErrorMessage} = 'Response looks like HTML instead of JSON.';
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'notice',
-            Message  => "SupportDataCollector - $Result{ErrorMessage}",
-        );
+
+        if ( $Self->{Debug} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'notice',
+                Message  => "SupportDataCollector - Response looks like HTML instead of JSON.",
+            );
+        }
+
         return %Result;
     }
 
@@ -315,22 +342,16 @@ sub CollectByWebRequest {
         Data => ${ $Response{Content} },
     );
     if ( !$ResponseData || ref $ResponseData ne 'HASH' ) {
-        $Result{ErrorMessage} = "Can't decode JSON: '" . ${ $Response{Content} } . "'!";
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "SupportDataCollector - $Result{ErrorMessage}",
-        );
+
+        if ( $Self->{Debug} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "SupportDataCollector - Can't decode JSON: '" . ${ $Response{Content} } . "'!",
+            );
+        }
         return %Result;
     }
 
-    # set cache
-    $Kernel::OM->Get('Kernel::System::Cache')->Set(
-        Type  => 'SupportDataCollect',
-        Key   => 'DataCollect',
-        Value => $ResponseData,
-        TTL   => 60 * 10,
-    );
-
     return %{$ResponseData};
 }
 
