@@ -1,6 +1,5 @@
 # --
-# Kernel/System/SupportDataCollector/Plugin/OS/PerlModules.pm - system data collector plugin
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,12 +13,14 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::Config',
 );
 
 sub GetDisplayPath {
-    return 'Operating System';
+    return Translatable('Operating System');
 }
 
 sub Run {
@@ -41,14 +42,14 @@ sub Run {
         )
     {
         $Self->AddResultProblem(
-            Label   => 'Perl Modules',
+            Label   => Translatable('Perl Modules'),
             Value   => $Output,
-            Message => 'Not all required Perl modules are correctly installed.',
+            Message => Translatable('Not all required Perl modules are correctly installed.'),
         );
     }
     else {
         $Self->AddResultOk(
-            Label => 'Perl Modules',
+            Label => Translatable('Perl Modules'),
             Value => $Output,
         );
     }
@@ -56,16 +57,4 @@ sub Run {
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
-
 1;
