@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::Language qw(Translatable);
 our @ObjectDependencies = ();
 
 sub GetDisplayPath {
-    return Translatable('Webserver/Loaded Apache Modules');
+    return Translatable('Webserver') . '/' . Translatable('Loaded Apache Modules');
 }
 
 sub Run {
@@ -26,9 +26,10 @@ sub Run {
 
     my %Environment = %ENV;
 
-    # No apache webserver with mod_perl, skip this check
+    # No web request or no apache webserver with mod_perl, skip this check.
     if (
-        !$ENV{SERVER_SOFTWARE}
+        !$ENV{GATEWAY_INTERFACE}
+        || !$ENV{SERVER_SOFTWARE}
         || $ENV{SERVER_SOFTWARE} !~ m{apache}i
         || !$ENV{MOD_PERL}
         || !eval { require Apache2::Module; }
@@ -48,16 +49,4 @@ sub Run {
     return $Self->GetResults()
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
-
 1;
