@@ -13,8 +13,12 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
+our @ObjectDependencies = ();
+
 sub GetDisplayPath {
-    return 'Webserver/Environment Variables';
+    return Translatable('Webserver') . '/' . Translatable('Environment Variables');
 }
 
 sub Run {
@@ -22,6 +26,9 @@ sub Run {
 
     my %Environment = %ENV;
 
+    # Skip the plugin, if the support data collection isn't running in a web request.
+    return $Self->GetResults() if !$ENV{GATEWAY_INTERFACE};
+
     for my $NotNeededString (
         qw(
         HTTP_REFERER HTTP_CACHE_CONTROL HTTP_COOKIE HTTP_USER_AGENT
@@ -50,16 +57,4 @@ sub Run {
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
-
 1;
