@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,6 +15,7 @@ use base qw(Kernel::System::SupportDataCollector::PluginAsynchronous);
 
 use Date::Pcalc qw(Add_Delta_YMD Add_Delta_DHMS);
 
+use Kernel::Language qw(Translatable);
 use Kernel::System::VariableCheck qw(:all);
 
 our @ObjectDependencies = (
@@ -36,7 +37,7 @@ sub Run {
 
     # the table details data
     $Self->AddResultInformation(
-        Label => 'Concurrent Users Details',
+        Label => Translatable('Concurrent Users Details'),
         Value => $ConcurrentUsers || [],
     );
 
@@ -74,7 +75,7 @@ sub Run {
         }
 
         $Self->AddResultInformation(
-            DisplayPath => 'OTRS/Concurrent Users',
+            DisplayPath => Translatable('OTRS') . '/' . Translatable('Concurrent Users'),
             Identifier  => $Identifier,
             Label       => "Max. $Label",
             Value       => $MaxValue,
@@ -246,16 +247,4 @@ sub RunAsynchronous {
     return 1;
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
-
 1;
