@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -425,6 +425,9 @@ sub TicketAcl {
                     for my $Item ( @{ $Step{$PropertiesHash}->{$Key}->{$Data} } ) {
                         if ( ref $UsedChecks{$Key}->{$Data} eq 'ARRAY' ) {
                             my $MatchItem = 0;
+                            if ( substr( $Item, 0, length '[Not' ) eq '[Not' ) {
+                                $MatchItem = 1;
+                            }
                             my $MatchedArrayDataItem;
                             ARRAYDATAITEM:
                             for my $ArrayDataItem ( @{ $UsedChecks{$Key}->{$Data} } ) {
@@ -2068,15 +2071,42 @@ sub _CompareMatchWithData {
     my $Match = $Param{Match};
     my $Data  = $Param{Data};
 
-    # Not equal match, this case requires a reverse logic than the rest
-    if ( substr( $Match, 0, length '[Not]' ) eq '[Not]' ) {
-        my $NotValue = substr $Match, length '[Not]';
-        if ( $NotValue eq $Data ) {
-            return {
-                Success => 1,
-                Match   => 0,
-            };
+    # Negated matches requires a different logic.
+    if ( substr( $Match, 0, length '[Not' ) eq '[Not' ) {
+
+        # Not equal match
+        if ( substr( $Match, 0, length '[Not]' ) eq '[Not]' ) {
+            my $NotValue = substr $Match, length '[Not]';
+            if ( $NotValue eq $Data ) {
+                return {
+                    Success => 1,
+                    Match   => 0,
+                };
+            }
         }
+
+        # Not reg-exp match case-sensitive.
+        elsif ( substr( $Match, 0, length '[NotRegExp]' ) eq '[NotRegExp]' ) {
+            my $RegExp = substr $Match, length '[NotRegExp]';
+            if ( $Data =~ /$RegExp/ ) {
+                return {
+                    Success => 1,
+                    Match   => 0,
+                };
+            }
+        }
+
+        # Not reg-exp match case-insensitive.
+        elsif ( substr( $Match, 0, length '[Notregexp]' ) eq '[Notregexp]' ) {
+            my $RegExp = substr $Match, length '[Notregexp]';
+            if ( $Data =~ /$RegExp/i ) {
+                return {
+                    Success => 1,
+                    Match   => 0,
+                };
+            }
+        }
+
         if ( $Param{SingleItem} ) {
             return {
                 Success => 1,
@@ -2092,72 +2122,52 @@ sub _CompareMatchWithData {
             };
         }
     }
-
-    # equal match
-    elsif ( $Match eq $Data ) {
-        return {
-            Success => 1,
-            Match   => 1,
-        };
-    }
-
-    # reg-exp match case-sensitive
-    elsif ( substr( $Match, 0, length '[RegExp]' ) eq '[RegExp]' ) {
-        my $RegExp = substr $Match, length '[RegExp]';
-        if ( $Data =~ /$RegExp/ ) {
-            return {
-                Success => 1,
-                Match   => 1,
-            };
-        }
-    }
-
-    # reg-exp match case-insensitive
-    elsif ( substr( $Match, 0, length '[regexp]' ) eq '[regexp]' ) {
-        my $RegExp = substr $Match, length '[regexp]';
-        if ( $Data =~ /$RegExp/i ) {
-            return {
-                Success => 1,
-                Match   => 1,
-            };
-        }
-    }
-
-    # not reg-exp match case-sensitive
-    elsif ( substr( $Match, 0, length '[NotRegExp]' ) eq '[NotRegExp]' ) {
-        my $RegExp = substr $Match, length '[NotRegExp]';
-        if ( $Data !~ /$RegExp/ ) {
-            return {
-                Success => 1,
-                Match   => 1,
-            };
-        }
-    }
-
-    # not reg-exp match case-insensitive
-    elsif ( substr( $Match, 0, length '[Notregexp]' ) eq '[Notregexp]' ) {
-        my $RegExp = substr $Match, length '[Notregexp]';
-        if ( $Data !~ /$RegExp/i ) {
-            return {
-                Success => 1,
-                Match   => 1,
-            };
-        }
-    }
-
-    if ( $Param{SingleItem} ) {
-        return {
-            Success => 1,
-            Match   => 0,
-            Skip    => 0,
-        };
-    }
     else {
-        return {
-            Success => 1,
-            Match   => 0,
-            Skip    => 1,
-        };
+
+        # Equal match.
+        if ( $Match eq $Data ) {
+            return {
+                Success => 1,
+                Match   => 1,
+            };
+        }
+
+        # Reg-exp match case-sensitive.
+        elsif ( substr( $Match, 0, length '[RegExp]' ) eq '[RegExp]' ) {
+            my $RegExp = substr $Match, length '[RegExp]';
+            if ( $Data =~ /$RegExp/ ) {
+                return {
+                    Success => 1,
+                    Match   => 1,
+                };
+            }
+        }
+
+        # Reg-exp match case-insensitive.
+        elsif ( substr( $Match, 0, length '[regexp]' ) eq '[regexp]' ) {
+            my $RegExp = substr $Match, length '[regexp]';
+            if ( $Data =~ /$RegExp/i ) {
+                return {
+                    Success => 1,
+                    Match   => 1,
+                };
+            }
+        }
+
+        if ( $Param{SingleItem} ) {
+            return {
+                Success => 1,
+                Match   => 0,
+                Skip    => 0,
+            };
+        }
+        else {
+            return {
+                Success => 1,
+                Match   => 0,
+                Skip    => 1,
+            };
+        }
     }
 }
 
