@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,7 @@ use warnings;
 
 use Term::ANSIColor();
 use SOAP::Lite;
+use FileHandle;
 
 use Kernel::System::ObjectManager;
 ## nofilter(TidyAll::Plugin::OTRS::Perl::ObjectManagerCreation)
@@ -86,6 +87,9 @@ sub new {
     $Self->{XML}     = undef;
     $Self->{XMLUnit} = '';
 
+    $Self->{OriginalSTDOUT} = *STDOUT;
+    $Self->{OriginalSTDOUT}->autoflush(1);
+
     return $Self;
 }
 
@@ -94,10 +98,12 @@ sub new {
 Run all tests located in scripts/test/*.t and print result to stdout.
 
     $UnitTestObject->Run(
-        Name      => 'JSON:User:Auth',  # optional, control which tests to select
-        Directory => 'Selenium',        # optional, control which tests to select
-
-        SubmitURL => $URL,              # optional, send results to unit test result server
+        Name                   => 'JSON:User:Auth',  # optional, control which tests to select
+        Directory              => 'Selenium',        # optional, control which tests to select
+        SubmitURL              => $URL,              # optional, send results to unit test result server
+        SubmitResultAsExitCode => $URL,              # optional, specify if exit code should not indicate if
+                                                     #   tests were ok/not ok, but if submission was successful instead.
+        Verbose                => 1,                 # optional (default 0), only show result details for all tests, not just failing
     );
 
 =cut
@@ -116,6 +122,8 @@ sub Run {
         $Directory =~ s/\.//g;
     }
 
+    $Self->{Verbose} = $Param{Verbose};
+
     my @Files = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
         Directory => $Directory,
         Filter    => '*.t',
@@ -175,15 +183,27 @@ sub Run {
 
                 push @{ $Self->{NotOkInfo} }, [$File];
 
+                $Self->{OutputBuffer} = '';
+                local *STDOUT = *STDOUT;
+                local *STDERR = *STDERR;
+                if ( !$Param{Verbose} ) {
+                    undef *STDOUT;
+                    undef *STDERR;
+                    open STDOUT, '>:utf8', \$Self->{OutputBuffer};    ## no critic
+                    open STDERR, '>:utf8', \$Self->{OutputBuffer};    ## no critic
+                }
+
                 # HERE the actual tests are run!!!
-                if ( !eval ${$UnitTestFile} ) {    ## no critic
+                if ( !eval ${$UnitTestFile} ) {                       ## no critic
                     if ($@) {
                         $Self->True( 0, "ERROR: Error in $File: $@" );
-                        print STDERR "ERROR: Error in $File: $@\n";
+
+                        #print STDERR "ERROR: Error in $File: $@\n";
                     }
                     else {
                         $Self->True( 0, "ERROR: $File did not return a true value." );
-                        print STDERR "ERROR: $File did not return a true value.\n";
+
+                        #print STDERR "ERROR: $File did not return a true value.\n";
                     }
                 }
             }
@@ -236,6 +256,9 @@ sub Run {
             $Content =~ s/&/&amp;/g;
             $Content =~ s/</&lt;/g;
             $Content =~ s/>/&gt;/g;
+
+            # Replace characters that are invalid in XML (https://www.w3.org/TR/REC-xml/#charsets)
+            $Content =~ s/[^\x{0009}\x{000a}\x{000d}\x{0020}-\x{D7FF}\x{E000}-\x{FFFD}]+/"\x{FFFD}"/eg;
             $XML .= qq|  <Test Result="$Result" Count="$TestCount">$Content</Test>\n|;
         }
 
@@ -255,8 +278,18 @@ sub Run {
             uri   => 'http://localhost/Core',
         );
 
-        my $Key = $RPC->Submit( '', '', $XML )->result();
-        print STDERR "NOTICE: Sent to $Param{SubmitURL} with SubmitID: '$Key'.\n";
+        eval {
+            my $Key = $RPC->Submit( '', '', $XML )->result();
+        };
+        if ($@) {
+            die "Could not submit results to server: $@";
+        }
+
+        print "Sent results to $Param{SubmitURL}.\n";
+
+        if ( $Param{SubmitResultAsExitCode} ) {
+            return 1;
+        }
     }
 
     return $ResultSummary{TestNotOk} ? 0 : 1;
@@ -785,6 +818,7 @@ sub _PrintHeadlineEnd {
         $Self->{Content} .= "</table><br>\n";
     }
     elsif ( $Self->{Output} eq 'ASCII' ) {
+        print "\n";
     }
 
     # calculate duration time
@@ -811,6 +845,11 @@ sub _Print {
         $PrintName = substr( $PrintName, 0, 1000 ) . "...";
     }
 
+    if ( $Self->{Output} eq 'ASCII' && ( $Self->{Verbose} || !$Test ) ) {
+        print { $Self->{OriginalSTDOUT} } $Self->{OutputBuffer};
+    }
+    $Self->{OutputBuffer} = '';
+
     $Self->{TestCount}++;
     if ($Test) {
         $Self->{TestCountOk}++;
@@ -819,7 +858,14 @@ sub _Print {
                 .= "<tr><td width='70' bgcolor='green'>ok $Self->{TestCount}</td><td>$Name</td></tr>\n";
         }
         elsif ( $Self->{Output} eq 'ASCII' ) {
-            print " " . $Self->_Color( 'green', "ok" ) . " $Self->{TestCount} - $PrintName\n";
+            if ( $Self->{Verbose} ) {
+                print { $Self->{OriginalSTDOUT} } " "
+                    . $Self->_Color( 'green', "ok" )
+                    . " $Self->{TestCount} - $PrintName\n";
+            }
+            else {
+                print { $Self->{OriginalSTDOUT} } $Self->_Color( 'green', "." );
+            }
         }
         $Self->{XML}->{Test}->{ $Self->{XMLUnit} }->{ $Self->{TestCount} }->{Result} = 'ok';
         $Self->{XML}->{Test}->{ $Self->{XMLUnit} }->{ $Self->{TestCount} }->{Name}   = $Name;
@@ -832,7 +878,12 @@ sub _Print {
                 .= "<tr><td width='70' bgcolor='red'>not ok $Self->{TestCount}</td><td>$Name</td></tr>\n";
         }
         elsif ( $Self->{Output} eq 'ASCII' ) {
-            print " " . $Self->_Color( 'red', "not ok" ) . " $Self->{TestCount} - $PrintName\n";
+            if ( !$Self->{Verbose} ) {
+                print { $Self->{OriginalSTDOUT} } "\n";
+            }
+            print { $Self->{OriginalSTDOUT} } " "
+                . $Self->_Color( 'red', "not ok" )
+                . " $Self->{TestCount} - $PrintName\n";
         }
         $Self->{XML}->{Test}->{ $Self->{XMLUnit} }->{ $Self->{TestCount} }->{Result} = 'not ok';
         $Self->{XML}->{Test}->{ $Self->{XMLUnit} }->{ $Self->{TestCount} }->{Name}   = $Name;
