@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -145,8 +145,12 @@ sub FormIDRemoveFile {
     }
 
     my @Index = @{ $Self->FormIDGetAllFilesMeta(%Param) };
-    my $ID    = $Param{FileID} - 1;
-    my %File  = %{ $Index[$ID] };
+
+    # finish if files have been already removed by other process
+    return if !@Index;
+
+    my $ID   = $Param{FileID} - 1;
+    my %File = %{ $Index[$ID] };
 
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
