@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -1125,7 +1125,6 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
                      },
                      {
                          Label: TargetNS.Localization.CancelMsg,
-                         Class: 'CallForAction',
                          Function: function () {
                              Core.UI.Dialog.CloseDialog($('.Dialog'));
                          }
@@ -1152,9 +1151,6 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
                 $('#Display').find('option[value=0]').remove();
             }
 
-            // redraw display field
-            $('#Display').trigger('redraw.InputField');
-
             // if there is a field config already the default settings from above are now overwritten
             if (typeof FieldConfig !== 'undefined') {
                 $('#DescShort').val(FieldConfig.DescriptionShort);
@@ -1176,9 +1172,11 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
                         $('#TimeUnits').val(FieldConfig.Config.TimeUnits);
                     }
                 }
-
             }
 
+            // redraw display field
+            $('#Display').trigger('redraw.InputField');
+
             // some fields do not have a default value.
             // disable the input field
             if ($.inArray(Fieldname, FieldsWithoutDefaultValue) > -1) {
@@ -1506,9 +1504,9 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
     TargetNS.HideOverlay = function () {
         $('#Overlay').remove();
         $('body').css({
-            'overflow': 'auto'
+            'overflow': 'visible',
+            'min-height': 0
         });
-        $('body').css('min-height', 'auto');
     };
 
     /**
@@ -1567,6 +1565,12 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             return false;
         }
 
+        // IE (11) has some permission problems with objects from other windows
+        // Therefore we "copy" the object if we are in IE
+        if ($.browser.trident) {
+            Config = Core.JSON.Parse(Core.JSON.Stringify(Config));
+        }
+
         // Update config from e.g. popup windows
 
         // Update Process
