@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -183,6 +183,9 @@ Core.Agent.TicketZoom = (function (TargetNS) {
                 return false;
             });
 
+            // Initialize modernized input fields in article action menu
+            Core.UI.InputFields.Activate($('#ArticleItems'));
+
             // Add event bindings to new widget
             Core.UI.InitWidgetActionToggle();
 
@@ -379,6 +382,9 @@ Core.Agent.TicketZoom = (function (TargetNS) {
 
         // loading new articles
         $('#ArticleTable tbody tr').bind('click', function () {
+
+            Core.App.Publish('Event.Agent.TicketZoom.ArticleClick');
+
             // Mode: show one article - load new article via ajax
             if (!ZoomExpand) {
                 // Add active state to new row
