@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -122,6 +122,22 @@ Core.Agent = (function (TargetNS) {
             }
         }
 
+        /**
+         * @private
+         * @name SetNavContainerHeight
+         * @memberof Core.Agent.InitNavigation
+         * @function
+         * @param {jQueryObject} $ParentElement
+         * @description
+         *      This function sets the nav container height according to the required height of the currently expanded sub menu
+         *      Due to the needed overflow: hidden property of the container, they would be hidden otherwise
+         */
+        function SetNavContainerHeight($ParentElement) {
+            if ($ParentElement.find('ul').length) {
+                $('#NavigationContainer').css('height', parseInt(InitialNavigationContainerHeight, 10) + parseInt($ParentElement.find('ul').outerHeight(), 10));
+            }
+        }
+
         $('#Navigation > li')
             .addClass('CanDrag')
             .filter(function () {
@@ -144,10 +160,8 @@ Core.Agent = (function (TargetNS) {
                         $Element.addClass('Active').attr('aria-expanded', true)
                             .siblings().removeClass('Active');
 
-                        // Resize the container in order to display subitems
-                        // Due to the needed overflow: hidden property of the
-                        // container, they would be hidden otherwise
-                        $('#NavigationContainer').css('height', '500px');
+                        // resize the nav container
+                        SetNavContainerHeight($Element);
 
                         // If Timeout is set for this nav element, clear it
                         ClearSubnavCloseTimeout($Element);
@@ -183,6 +197,11 @@ Core.Agent = (function (TargetNS) {
                 var $Element = $(this),
                     $Target = $(Event.target);
 
+                // if an onclick attribute is present, the attribute should win
+                if ($Target.attr('onclick')) {
+                    return false;
+                }
+
                 // if OpenMainMenuOnHover is enabled, clicking the item
                 // should lead to the link as regular
                 if ($('body').hasClass('Visible-ScreenXL') && !Core.App.Responsive.IsTouchDevice() && Core.Config.Get('OpenMainMenuOnHover')) {
@@ -198,7 +217,7 @@ Core.Agent = (function (TargetNS) {
                 // That means that a subnavigation in mobile mode is still collapsed/expanded,
                 // although the link to the new page is clicked
                 // we force the redirect with this workaround
-                if ($Target.closest('ul').attr('id') !== 'Navigation') {
+                if (navigator && navigator.userAgent && navigator.userAgent.match(/Windows Phone/i) && $Target.closest('ul').attr('id') !== 'Navigation') {
                     window.location.href = $Target.closest('a').attr('href');
                     Event.stopPropagation();
                     Event.preventDefault();
@@ -219,7 +238,8 @@ Core.Agent = (function (TargetNS) {
 
                     if ($('body').hasClass('Visible-ScreenXL')) {
 
-                        $('#NavigationContainer').css('height', '300px');
+                        // resize the nav container
+                        SetNavContainerHeight($Element);
 
                         // If Timeout is set for this nav element, clear it
                         ClearSubnavCloseTimeout($Element);
@@ -609,6 +629,16 @@ Core.Agent = (function (TargetNS) {
         Core.UI.InputFields.Init();
         Core.UI.TreeSelection.InitTreeSelection();
         Core.UI.TreeSelection.InitDynamicFieldTreeViewRestore();
+
+        if (
+            typeof Core.Agent.Chat !== 'undefined'
+            && typeof Core.Agent.Chat.Toolbar !== 'undefined'
+            && typeof Core.Agent.Chat.Toolbar.InitChatButtons !== 'undefined'
+            )
+        {
+            Core.Agent.Chat.Toolbar.InitChatButtons();
+        }
+
         // late execution of accessibility code
         Core.UI.Accessibility.Init();
     };
