@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -45,12 +45,13 @@ Core.UI.RichTextEditor = (function (TargetNS) {
      * @memberof Core.UI.RichTextEditor
      * @function
      * @returns {jQueryObject} FormID element.
+     * @param {jQueryObject} $EditorArea - The jQuery object of the element that has become a rich text editor.
      * @description
      *      Check in the window which hidden element has a name same to 'FormID' and return it like a JQuery object.
      */
-    function CheckFormID() {
+    function CheckFormID($EditorArea) {
         if (typeof $FormID === 'undefined') {
-            $FormID = $('input:hidden[name=FormID]');
+            $FormID = $EditorArea.closest('form').find('input:hidden[name=FormID]');
         }
         return $FormID;
     }
@@ -117,12 +118,13 @@ Core.UI.RichTextEditor = (function (TargetNS) {
         UserLanguage = Core.Config.Get('UserLanguage').replace(/_/, "-");
 
         // build URL for image upload
-        if (CheckFormID().length) {
+        if (CheckFormID($EditorArea).length) {
+
             UploadURL = Core.Config.Get('Baselink')
                     + 'Action='
                     + Core.Config.Get('RichText.PictureUploadAction', 'PictureUpload')
                     + '&FormID='
-                    + CheckFormID().val()
+                    + CheckFormID($EditorArea).val()
                     + '&' + Core.Config.Get('SessionName')
                     + '=' + Core.Config.Get('SessionID');
         }
@@ -136,7 +138,7 @@ Core.UI.RichTextEditor = (function (TargetNS) {
             width: Core.Config.Get('RichText.Width', 620),
             resize_minWidth: Core.Config.Get('RichText.Width', 620),
             height: Core.Config.Get('RichText.Height', 320),
-            removePlugins: CheckFormID().length ? '' : 'image2,uploadimage',
+            removePlugins: CheckFormID($EditorArea).length ? '' : 'image2,uploadimage',
             forcePasteAsPlainText: false,
             format_tags: 'p;h1;h2;h3;h4;h5;h6;pre',
             fontSize_sizes: '8px;10px;12px;16px;18px;20px;22px;24px;26px;28px;30px;',
@@ -145,10 +147,10 @@ Core.UI.RichTextEditor = (function (TargetNS) {
             shiftEnterMode: CKEDITOR.ENTER_BR,
             contentsLangDirection: Core.Config.Get('RichText.TextDir', 'ltr'),
             disableNativeSpellChecker: false,
-            toolbar: CheckFormID().length ? Core.Config.Get('RichText.Toolbar') : Core.Config.Get('RichText.ToolbarWithoutImage'),
+            toolbar: CheckFormID($EditorArea).length ? Core.Config.Get('RichText.Toolbar') : Core.Config.Get('RichText.ToolbarWithoutImage'),
             filebrowserBrowseUrl: '',
             filebrowserUploadUrl: UploadURL,
-            extraPlugins: Core.Config.Get('RichText.SpellChecker') ? 'aspell,splitquote' : 'splitquote',
+            extraPlugins: Core.Config.Get('RichText.SpellChecker') ? 'aspell,splitquote,contextmenu_linkopen,preventimagepaste' : 'splitquote,contextmenu_linkopen,preventimagepaste',
             entities: false,
             skin: 'bootstrapck'
         });
