@@ -22,6 +22,12 @@ nv.models.OTRSstackedAreaChart = function() {
         , showXAxis = true
         , showYAxis = true
         , rightAlignYAxis = false
+// ---
+// OTRS
+// ---
+        , reduceXTicks = true
+        , staggerLabels = false
+// ---
         , useInteractiveGuideline = false
         , tooltips = true
         , tooltip = function(key, x, y, e, graph) {
@@ -47,7 +53,12 @@ nv.models.OTRSstackedAreaChart = function() {
         ;
 
     state.style = stacked.style();
-    xAxis.orient('bottom').tickPadding(7);
+// ---
+// OTRS
+// ---
+//    xAxis.orient('bottom').tickPadding(7);
+    xAxis.orient('bottom').tickPadding(7).showMaxMin(false);
+// ---
     yAxis.orient((rightAlignYAxis) ? 'right' : 'left');
 
     controls.updateState(false);
@@ -273,6 +284,42 @@ nv.models.OTRSstackedAreaChart = function() {
                 g.select('.nv-x.nv-axis')
                     .transition().duration(0)
                     .call(xAxis);
+// ---
+// OTRS
+// ---
+                var xTicks = g.select('.nv-x.nv-axis > g').selectAll('g');
+
+                xTicks
+                    .selectAll('line, text')
+                    .style('opacity', 1)
+                if (staggerLabels) {
+                    var getTranslate = function(x,y) {
+                        return "translate(" + x + "," + y + ")";
+                    };
+
+                    var staggerUp = 5, staggerDown = 17;  //pixels to stagger by
+                    // Issue #140
+                    xTicks
+                        .selectAll("text")
+                        .attr('transform', function(d,i,j) {
+                            return  getTranslate(0, (j % 2 == 0 ? staggerUp : staggerDown));
+                        });
+
+                    var totalInBetweenTicks = d3.selectAll(".nv-x.nv-axis .nv-wrap g g text")[0].length;
+                    g.selectAll(".nv-x.nv-axis .nv-axisMaxMin text")
+                        .attr("transform", function(d,i) {
+                            return getTranslate(0, (i === 0 || totalInBetweenTicks % 2 !== 0) ? staggerDown : staggerUp);
+                        });
+                }
+
+                if (reduceXTicks)
+                    xTicks
+                        .filter(function(d,i) {
+                            return i % Math.ceil(data[0].values.length / (availableWidth / 100)) !== 0;
+                        })
+                        .selectAll('text, line')
+                        .style('opacity', 0);
+// ---
             }
 
             if (showYAxis) {
@@ -486,6 +533,12 @@ nv.models.OTRSstackedAreaChart = function() {
         noData:    {get: function(){return noData;}, set: function(_){noData=_;}},
         showControls:    {get: function(){return showControls;}, set: function(_){showControls=_;}},
         controlLabels:    {get: function(){return controlLabels;}, set: function(_){controlLabels=_;}},
+// ---
+// OTRS
+// ---
+        reduceXTicks:    {get: function(){return reduceXTicks;}, set: function(_){reduceXTicks=_;}},
+        staggerLabels:    {get: function(){return staggerLabels;}, set: function(_){staggerLabels=_;}},
+// ---
         yAxisTickFormat:    {get: function(){return yAxisTickFormat;}, set: function(_){yAxisTickFormat=_;}},
 
         // options that require extra logic in the setter
